@@ -10,7 +10,7 @@
 'use strict';
 
 var Utilities = {
-	VERSION	: "3.0.13",
+	VERSION	: "3.1",
 
 	exc : function() {
 		console.error.apply(console, arguments);
@@ -167,20 +167,20 @@ var Utilities = {
 			return "us";
 		}
 		var layout = LANGUAGE_TO_LAYOUT[v];
-		if (layout) {
-			return layout;
+		if (!layout) {
+			//ie: v="en_GB";
+			v = v.split(',')[0];
+			let l = v.split('-', 2);
+			if (l.length === 1){
+				l = v.split('_', 2);
+			}
+			//ie: "en"
+			layout = l[0].toLowerCase();
+			const tmp = LANGUAGE_TO_LAYOUT[v];
+			if (tmp) {
+				layout = tmp;
+			}
 		}
-		//ie: v="en_GB";
-		v = v.split(',')[0];
-		var l = v.split('-', 2);
-		if (l.length === 1){
-			l = v.split('_', 2);
-		}
-		if (l.length === 1){
-			return '';
-		}
-		//ie: "en"
-		layout = l[0].toLowerCase();
 		Utilities.debug("getKeyboardLayout()=", layout);
 		return layout;
 	},
@@ -604,6 +604,97 @@ var MOVERESIZE_DIRECTION_JS_NAME = {
         };
 
 //convert a language code into an X11 keyboard layout code:
-var LANGUAGE_TO_LAYOUT = {
+const LANGUAGE_TO_LAYOUT = {
+		"en_GB"	: "gb",
+		"en"	: "us",
+		"zh"	: "cn",
+		"af"	: "za",
+		"sq"	: "al",
+		//"ar"	: "ar",
+		//"eu"	: "eu",
+		//"bg"	: "bg",
+		//"be"	: "be",
+		"ca"	: "ca",
+		"zh-TW"	: "tw",
+		"zh-CN"	: "cn",
+		//"zh-HK"	: ??
+		//"zh-SG"	: ??
+		//"hr"	: "hr",
+		"cs"	: "cz",
 		"da"	: "dk",
-}
+		//"nl"	: "nl",
+		"nl-BE"	: "be",
+		"en-US"	: "us",
+		//"en-EG"	: ??
+		"en-AU"	: "us",
+		"en-GB"	: "gb",
+		"en-CA"	: "ca",
+		"en-NZ"	: "us",
+		"en-IE"	: "ie",
+		"en-ZA" : "za",
+		"en-JM" : "us",
+		//"en-BZ"	: ??
+		"en-TT"	: "tr",
+		"et"	: "ee",
+		//"fo"	: "fo",
+		"fa"	: "ir",
+		//"fi"	: "fi",
+		//"fr"	: "fr",
+		"fr-BE"	: "be",
+		"fr-CA"	: "ca",
+		"fr-CH"	: "ch",
+		"fr-LU"	: "fr",
+		//"gd"	: ??
+		"gd-IE"	: "ie",
+		//"de"	: "de",
+		"de-CH"	: "ch",
+		"de-AT"	: "at",
+		"de-LU"	: "de",
+		"de-LI"	: "de",
+		"he"	: "il",
+		"hi"	: "in",
+		//"hu"	: "hu",
+		//"is"	: "is",
+		//"id"	: ??,
+		//"it"	: "it",
+		"it-CH"	: "ch",
+		"ja"	: "jp",
+		"ko"	: "kr",
+		//"lv"	: "lv",
+		//"lt"	: "lt",
+		//"mk"	: "mk",
+		//"mt"	: "mt",
+		//"no"	: "no",
+		//"pl"	: "pl",
+		"pt-BR"	: "br",
+		"pt"	: "pt",
+		//"rm"	: ??,
+		//"ro"	: "ro",
+		//"ro-MO"	: ??,
+		//"ru"	: "ru",
+		///"ru-MI"	: ??,
+		//"sz"	: ??,
+		"sr"	: "rs",
+		//"sk"	: "sk",
+		"sl"	: "si",
+		//"sb"	: ??,
+		"es"	: "es",
+		//"es-AR", "es-GT", "es-CR", "es-PA", "es-DO", "es-MX", "es-VE", "es-CO",
+		//"es-PE", "es-EC", "es-CL", "es-UY", "es-PY", "es-BO", "es-SV", "es-HN",
+		//"es-NI", "es-PR",
+		//"sx"	: ??,
+		"sv"	: "se",
+		"sv-FI"	: "fi",
+		//"th"	: "th",
+		//"ts"	: ??,
+		//"tn"	: ??,
+		"tr"	: "tr",
+		"uk"	: "ua",
+		"ur"	: "pk",
+		//"ve"	: ??,
+		"vi"	: "vn",
+		//"xh"	: "??",
+ 		//"ji"	: "??",
+		//"zu"	: "??",
+};
+
