@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # This file is part of Xpra.
-# Copyright (C) 2014 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2014 Antoine Martin <antoine@xpra.org>
 
 #need to find a generic way to discover tests
 #that works with python2.6 without introducing more dependencies
@@ -39,8 +39,8 @@ def main():
         cmd = ["python%s" % sys.version_info[0], p]
         try:
             proc = subprocess.Popen(cmd)
-        except:
-            write("failed to execute %s" % p)
+        except OSError as e:
+            write("failed to execute %s: %s" % (p, e))
             return 1
         v = proc.wait()
         if v!=0:
@@ -71,5 +71,4 @@ def main():
             run_file(x)
 
 if __name__ == '__main__':
-    v = main()
-    sys.exit(v)
+    sys.exit(main())
