@@ -34,3 +34,5 @@ class GLClientWindowBase(GLClientWindowCommon, GTK3ClientWindow):
         self.init_widget_events(widget)
         self.add(widget)
         self.drawing_area = widget
+        #maybe redundant?:
+        self.apply_geometry_hints(self.geometry_hints)
