@@ -1,10 +1,10 @@
 # This file is part of Xpra.
 # Copyright (C) 2008 Nathaniel Smith <njs@pobox.com>
-# Copyright (C) 2012-2018 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2012-2021 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-import cairo
+from cairo import ImageSurface  #pylint: disable=no-name-in-module
 from gi.repository import GLib              #@UnresolvedImport
 from gi.repository import GdkPixbuf         #@UnresolvedImport
 
@@ -15,13 +15,14 @@ from xpra.log import Logger
 log = Logger("paint", "cairo")
 
 try:
-    from xpra.client.gtk3.cairo_workaround import set_image_surface_data    #@UnresolvedImport
+    from xpra.client.gtk3.cairo_workaround import set_image_surface_data, CAIRO_FORMATS #@UnresolvedImport
 except ImportError as e:
     log.warn("Warning: failed to load the gtk3 cairo workaround:")
     log.warn(" %s", e)
     log.warn(" rendering will be slow!")
     del e
     set_image_surface_data = None
+    CAIRO_FORMATS = {}
 
 
 CAIRO_USE_PIXBUF = envbool("XPRA_CAIRO_USE_PIXBUF", False)
@@ -38,10 +39,15 @@ Instead we have to use PIL to convert via a PNG or Pixbuf!
 """
 class CairoBacking(CairoBackingBase):
 
-    RGB_MODES = ["BGRA", "BGRX", "RGBA", "RGBX", "BGR", "RGB"]
+    RGB_MODES = ["BGRA", "BGRX", "RGBA", "RGBX", "BGR", "RGB", "r210", "BGR565"]
 
     def __repr__(self):
-        return "gtk3.CairoBacking(%s)" % self._backing
+        b = self._backing
+        if b:
+            binfo = "ImageSurface(%i, %i)" % (b.get_width(), b.get_height())
+        else:
+            binfo = "None"
+        return "gtk3.CairoBacking(%s : size=%s)" % (binfo, self.size)
 
     def _do_paint_rgb(self, cairo_format, has_alpha, img_data, x, y, width, height, rowstride, options):
         """ must be called from UI thread """
@@ -51,12 +57,14 @@ class CairoBacking(CairoBackingBase):
             rowstride, options, set_image_surface_data, CAIRO_USE_PIXBUF)
         rgb_format = options.strget(b"rgb_format", "RGB")
         if set_image_surface_data and not CAIRO_USE_PIXBUF:
-            if (cairo_format==cairo.FORMAT_RGB24 and rgb_format in ("RGB", "RGBX", "BGR", "BGRX")) or \
-                (cairo_format==cairo.FORMAT_ARGB32 and rgb_format in ("BGRX", "BGRA")):
-                img_surface = cairo.ImageSurface(cairo_format, width, height)
+            rgb_formats = CAIRO_FORMATS.get(cairo_format)
+            if rgb_format in rgb_formats:
+                img_surface = ImageSurface(cairo_format, width, height)
                 set_image_surface_data(img_surface, rgb_format, img_data, width, height, rowstride)
-                self.cairo_paint_surface(img_surface, x, y, options)
+                self.cairo_paint_surface(img_surface, x, y, width, height, options)
                 return True
+            log("cannot set image surface data for cairo format %s and rgb_format %s (rgb formats supported: %s)",
+                cairo_format, rgb_format, rgb_formats)
 
         if rgb_format in ("RGB", "RGBA", "RGBX"):
             data = GLib.Bytes(img_data)
