@@ -36,7 +36,7 @@ from xpra.gtk_common.gtk_util import (
     DEST_DEFAULT_MOTION, DEST_DEFAULT_HIGHLIGHT, ACTION_COPY,
     BUTTON_PRESS_MASK, BUTTON_RELEASE_MASK, POINTER_MOTION_MASK,
     POINTER_MOTION_HINT_MASK, ENTER_NOTIFY_MASK, LEAVE_NOTIFY_MASK,
-    WINDOW_EVENT_MASK,
+    WINDOW_EVENT_MASK, SMOOTH_SCROLL_MASK,
     )
 from xpra.gtk_common.keymap import KEY_TRANSLATIONS
 from xpra.client.client_window_base import ClientWindowBase
@@ -225,6 +225,7 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
         self._current_frame_extents = None
         self._screen = -1
         self._frozen = False
+        self._focus_latest = None
         self.window_state_timer = None
         self.send_iconify_timer = None
         self.remove_pointer_overlay_timer = None
@@ -398,7 +399,6 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
                 log.warn("Warning: missing gdk bindings:")
                 log.warn(" %s", e)
             else:
-                self._focus_latest = None
                 grablog("adding event receiver so we can get FocusIn and FocusOut events whilst grabbing the keyboard")
                 add_event_receiver(self.get_window(), self)
         #other platforms should bet getting regular focus events instead:
@@ -1818,10 +1818,9 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
                 window.move(x+dx, y+dy)
         geomlog("configure event: current size=%s, new size=%s, backing=%s, iconified=%s",
                 self._size, (w, h), self._backing, self._iconified)
-        if (w, h) != self._size or (self._backing is None and not self._iconified):
-            self._size = (w, h)
-            self._set_backing_size(w, h)
-        elif self._backing and not self._iconified:
+        self._size = (w, h)
+        self._set_backing_size(w, h)
+        if self._backing and not self._iconified:
             geomlog("configure event: size unchanged, queueing redraw")
             self.queue_draw_area(0, 0, w, h)
 
@@ -1864,10 +1863,16 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
 
     def _set_backing_size(self, ww, wh):
         b = self._backing
+        bw = self._client.cx(ww)
+        bh = self._client.cy(wh)
+        if max(ww, wh)>=32000 or min(ww, wh)<0:
+            raise Exception("invalid window size %ix%i" % (ww, wh))
+        if max(bw, bh)>=32000:
+            raise Exception("invalid window backing size %ix%i" % (bw, bh))
         if b:
-            b.init(ww, wh, self._client.cx(ww), self._client.cy(wh))
+            b.init(ww, wh, bw, bh)
         else:
-            self.new_backing(self._client.cx(ww), self._client.cy(wh))
+            self.new_backing(bw, bh)
 
     def resize(self, w, h, resize_counter=0):
         ww, wh = self.get_size()
@@ -2116,6 +2121,10 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
     def _do_scroll_event(self, event):
         if self._client.readonly:
             return
+        if SMOOTH_SCROLL_MASK and event.direction==SMOOTH_SCROLL_MASK:
+            mouselog("smooth scroll event: %s", event)
+            self._client.wheel_event(self._id, event.delta_x, -event.delta_y)
+            return
         button_mapping = GDK_SCROLL_MAP.get(event.direction, -1)
         mouselog("do_scroll_event device=%s, direction=%s, button_mapping=%s",
                  self._device_info(event), event.direction, button_mapping)
