@@ -451,6 +451,7 @@ class GTKTrayMenuBase(object):
             menu.append(self.make_modalwindowmenuitem())
         if mixin_features.windows and self.client.keyboard_helper:
             menu.append(self.make_keyboardsyncmenuitem())
+            menu.append(self.make_shortcutsmenuitem())
 
     def make_sharingmenuitem(self):
         def sharing_toggled(*args):
@@ -685,13 +686,12 @@ class GTKTrayMenuBase(object):
             if not c.server_clipboard:
                 self.clipboard_menuitem.set_tooltip_text("Server does not support clipboard synchronization")
                 return
-            if not c.client_supports_clipboard:
+            ch = c.clipboard_helper
+            if not c.client_supports_clipboard or not ch:
                 self.clipboard_menuitem.set_tooltip_text("Client does not support clipboard synchronization")
                 return
             #add a submenu:
             set_sensitive(self.clipboard_menuitem, True)
-            c = self.client
-            ch = self.client.clipboard_helper
             clipboard_submenu = gtk.Menu()
             self.clipboard_menuitem.set_submenu(clipboard_submenu)
             self.popup_menu_workaround(clipboard_submenu)
@@ -755,6 +755,18 @@ class GTKTrayMenuBase(object):
         self.client.after_handshake(set_keyboard_sync_menuitem)
         return self.keyboard_sync_menuitem
 
+    def make_shortcutsmenuitem(self):
+        self.keyboard_shortcuts_menuitem = self.checkitem("Keyboard Shortcuts")
+        kh = self.client.keyboard_helper
+        self.keyboard_shortcuts_menuitem.set_active(kh and bool(kh.shortcuts_enabled))
+        def keyboard_shortcuts_toggled(*args):
+            ks = self.keyboard_shortcuts_menuitem.get_active()
+            log("keyboard_shortcuts_toggled%s enabled=%s", args, ks)
+            kh.shortcuts_enabled = ks
+        self.keyboard_shortcuts_menuitem.connect("toggled", keyboard_shortcuts_toggled)
+        return self.keyboard_shortcuts_menuitem
+
+
     def make_openglmenuitem(self):
         gl = self.checkitem("OpenGL")
         gl.set_tooltip_text("hardware accelerated rendering using OpenGL")
@@ -1558,7 +1570,7 @@ class GTKTrayMenuBase(object):
             dialog.destroy()
             if response == SHUTDOWN:
                 self.client.send_shutdown_server()
-        self.shutdown = self.menuitem("Shutdown Server", "shutdown.png", cb=ask_shutdown_confirm)
+        self.shutdown = self.menuitem("Shutdown Session", "shutdown.png", cb=ask_shutdown_confirm)
         def enable_shutdown(*args):
             log("enable_shutdown%s can_shutdown_server=%s", args, self.client.server_client_shutdown)
             set_sensitive(self.shutdown, self.client.server_client_shutdown)
@@ -1623,7 +1635,11 @@ class GTKTrayMenuBase(object):
         pixbuf = None
         if app_name and not icondata:
             #try to load from our icons:
-            icon_filename = os.path.join(get_icon_dir(), "%s.png" % app_name.decode("utf-8").lower())
+            try:
+                nstr = app_name.decode("utf-8").lower()
+            except UnicodeDecodeError:
+                nstr = bytestostr(app_name).lower()
+            icon_filename = os.path.join(get_icon_dir(), "%s.png" % nstr)
             if os.path.exists(icon_filename):
                 from xpra.gtk_common.gtk_util import pixbuf_new_from_file
                 pixbuf = pixbuf_new_from_file(icon_filename)
