@@ -12,6 +12,7 @@ from xpra.gtk_common.gobject_compat import (
     import_gtk, import_pango, import_glib,
     register_os_signals,
     )
+from xpra.platform.gui import force_focus
 from xpra.os_util import get_util_logger
 from xpra.gtk_common.gtk_util import (
     gtk_main, add_close_accel, pixbuf_new_from_file, window_defaults,
@@ -35,7 +36,7 @@ class PasswordInputDialogWindow(object):
             self.window = gtk.Window(WINDOW_TOPLEVEL)
         window_defaults(self.window)
         self.window.set_position(WIN_POS_CENTER)
-        self.window.connect("destroy", self.quit)
+        self.window.connect("delete-event", self.quit)
         self.window.set_default_size(400, 150)
         self.window.set_title(title)
         self.window.set_modal(True)
@@ -99,8 +100,11 @@ class PasswordInputDialogWindow(object):
     def show(self):
         log("show()")
         self.window.show_all()
-        glib.idle_add(self.window.present)
-        glib.idle_add(self.password_input.grab_focus)
+        def show():
+            force_focus()
+            self.window.present()
+            self.password_input.grab_focus()
+        glib.idle_add(show)
 
     def destroy(self, *args):
         log("destroy%s", args)
@@ -118,6 +122,7 @@ class PasswordInputDialogWindow(object):
         log("quit%s", args)
         self.destroy()
         gtk.main_quit()
+        return True
 
     def activate(self, *args):
         log("activate%s", args)
@@ -140,9 +145,11 @@ class PasswordInputDialogWindow(object):
 def show_pass_dialog(argv):
     from xpra.platform.gui import ready as gui_ready
     from xpra.gtk_common.quit import gtk_main_quit_on_fatal_exceptions_enable
-    from xpra.platform.gui import init as gui_init
+    from xpra.platform.gui import init as gui_init, set_default_icon
 
+    set_default_icon("authentication.png")
     gui_init()
+
     gtk_main_quit_on_fatal_exceptions_enable()
 
     log("show_pass_dialog(%s)", argv)
