@@ -402,7 +402,7 @@ class SessionsGUI(gtk.Window):
         uri_menu = gtk.combo_box_new_text()
         uri_menu.set_size_request(340, 48)
         #sort by protocol so TCP comes first
-        order = {"socket" : 0, "ssh" : 1, "ssl" :2, "wss" : 3, "tcp" : 4, "ws" : 8}
+        order = {"socket" : 0, "ssh" : 1, "tcp" :2, "ssl" : 3, "ws" : 4, "wss" : 8}
         if WIN32:
             #on MS Windows, prefer ssh which has a GUI for accepting keys
             #and entering the password:
@@ -416,10 +416,13 @@ class SessionsGUI(gtk.Window):
             #prefer order (from mode), then shorter host string:
             return "%s-%s" % (order.get(mode, mode), host_len)
         srecs = sorted(recs, key=cmp_key)
+        has_ws = False
         for rec in srecs:
             uri = self.get_uri(None, *rec)
             uri_menu.append_text(uri)
             d[uri] = rec
+            if uri.startswith("ws"):
+                has_ws = True
         def connect(*_args):
             uri = uri_menu.get_active_text()
             rec = d[uri]
@@ -430,7 +433,14 @@ class SessionsGUI(gtk.Window):
         btn = imagebutton("Connect", icon, clicked_callback=connect)
         def uri_changed(*_args):
             uri = uri_menu.get_active_text()
-            bopen.set_sensitive(uri.startswith("ws"))
+            ws = uri.startswith("ws")
+            bopen.set_sensitive(ws)
+            if ws:
+                bopen.set_tooltip_text("")
+            elif not has_ws:
+                bopen.set_tooltip_text("no 'ws' or 'wss' URIs found")
+            else:
+                bopen.set_tooltip_text("select a 'ws' or 'wss' URI")
         uri_menu.connect("changed", uri_changed)
         uri_changed()
         def browser_open_option(*_args):
