@@ -11,6 +11,7 @@ from xpra.platform.gui import (
     get_antialias_info, get_icc_info, get_display_icc_info, show_desktop, get_cursor_size,
     get_xdpi, get_ydpi, get_number_of_desktops, get_desktop_names, get_wm_name,
     )
+from xpra.scripts.main import check_display
 from xpra.scripts.config import FALSE_OPTIONS
 from xpra.os_util import monotonic_time
 from xpra.util import (
@@ -48,6 +49,7 @@ class DisplayClient(StubClientMixin):
     __signals__ = ["scaling-changed"]
 
     def __init__(self):
+        check_display()
         StubClientMixin.__init__(self)
         self.dpi = 0
         self.initial_scaling = 1, 1
