@@ -112,17 +112,19 @@ class NotificationClient(StubClientMixin):
                 for x in body.splitlines():
                     log.info(" %s", x)
             return
-        try:
-            from xpra.notifications.common import parse_image_path
-            icon_filename = get_icon_filename(icon_name)
-            icon = parse_image_path(icon_filename)
-            n.show_notify("", self.tray, nid, "Xpra", nid, "",
-                          summary, body, actions, hints or {}, expire_timeout, icon)
-        except Exception as e:
-            log("failed to show notification", exc_info=True)
-            log.error("Error: cannot show notification")
-            log.error(" '%s'", summary)
-            log.error(" %s", e)
+        def show_notification():
+            try:
+                from xpra.notifications.common import parse_image_path
+                icon_filename = get_icon_filename(icon_name)
+                icon = parse_image_path(icon_filename)
+                n.show_notify("", self.tray, nid, "Xpra", nid, "",
+                              summary, body, actions, hints or {}, expire_timeout, icon)
+            except Exception as e:
+                log("failed to show notification", exc_info=True)
+                log.error("Error: cannot show notification")
+                log.error(" '%s'", summary)
+                log.error(" %s", e)
+        self.idle_add(show_notification)
 
     def _process_notify_show(self, packet):
         if not self.notifications_enabled:
@@ -138,7 +140,7 @@ class NotificationClient(StubClientMixin):
         #note: if the server doesn't support notification forwarding,
         #it can still send us the messages (via xpra control or the dbus interface)
         log("_process_notify_show(%s) notifier=%s, server_notifications=%s",
-            repr_ellipsized(str(packet)), self.notifier, self.server_notifications)
+            repr_ellipsized(packet), self.notifier, self.server_notifications)
         log("notification actions=%s, hints=%s", actions, hints)
         assert self.notifier
         #this one of the few places where we actually do care about character encoding:
