@@ -282,7 +282,7 @@ class WindowClient(StubClientMixin):
             "double_click.distance"     : get_double_click_distance(),
             #features:
             "bell"                      : self.client_supports_bell,
-            "vrefresh"                  : get_vrefresh(),
+            "vrefresh"                  : self.get_vrefresh(),
             "windows"                   : self.windows_enabled,
             "auto_refresh_delay"        : int(self.auto_refresh_delay*1000),
             #system tray forwarding:
@@ -307,6 +307,9 @@ class WindowClient(StubClientMixin):
             })
         return caps
 
+    def get_vrefresh(self):
+        return get_vrefresh()
+
     def get_window_caps(self):
         return {
             "raise"                     : True,
@@ -1047,8 +1050,8 @@ class WindowClient(StubClientMixin):
         aw = max(1, self.sx(w))
         ah = max(1, self.sy(h))
         resize_counter = -1
-        if len(packet)>4:
-            resize_counter = packet[4]
+        if len(packet)>6:
+            resize_counter = packet[6]
         window = self._id_to_window.get(wid)
         geomlog("_process_window_move_resize%s moving / resizing window %s (id=%s) to %s",
                 packet[1:], window, wid, (ax, ay, aw, ah))
