@@ -1,6 +1,6 @@
 # This file is part of Xpra.
 # Copyright (C) 2011 Serviware (Arthur Huillet, <ahuillet@serviware.com>)
-# Copyright (C) 2010-2019 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2010-2020 Antoine Martin <antoine@xpra.org>
 # Copyright (C) 2008, 2010 Nathaniel Smith <njs@pobox.com>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
@@ -10,14 +10,13 @@ import sys
 from xpra.client.client_base import XpraClientBase
 from xpra.client.keyboard_helper import KeyboardHelper
 from xpra.platform import set_name
-from xpra.platform.features import MMAP_SUPPORTED
 from xpra.platform.gui import ready as gui_ready, get_wm_name, get_session_type, ClientExtras
 from xpra.version_util import full_version_str
 from xpra.net import compression, packet_encoding
 from xpra.child_reaper import reaper_cleanup
 from xpra.os_util import platform_name, bytestostr, strtobytes, BITS, POSIX, is_Wayland
 from xpra.util import (
-    std, envbool, envint, typedict, updict, repr_ellipsized,
+    std, envbool, envint, typedict, updict, repr_ellipsized, ellipsizer, log_screen_sizes, engs,
     XPRA_AUDIO_NOTIFICATION_ID, XPRA_DISCONNECT_NOTIFICATION_ID,
     )
 from xpra.exit_codes import EXIT_CONNECTION_FAILED, EXIT_OK, EXIT_CONNECTION_LOST
@@ -208,8 +207,7 @@ class UIXpraClient(ClientBaseClass):
 
         if MOUSE_DELAY_AUTO:
             try:
-                from xpra.platform.gui import get_vrefresh
-                v = get_vrefresh()
+                v = self.get_vrefresh()
                 if v<=0:
                     #some platforms don't detect the vrefresh correctly
                     #(ie: macos in virtualbox?), so use a sane default:
@@ -219,6 +217,11 @@ class UIXpraClient(ClientBaseClass):
             except Exception:
                 log("failed to calculate automatic delay", exc_info=True)
 
+    def get_vrefresh(self):
+        #this method is overriden in the GTK client
+        from xpra.platform.gui import get_vrefresh
+        return get_vrefresh()
+
 
     def run(self):
         if self.client_extras:
@@ -341,7 +344,7 @@ class UIXpraClient(ClientBaseClass):
         caps["session-type"] = get_session_type()
         #don't try to find the server uuid if this platform cannot run servers..
         #(doing so causes lockups on win32 and startup errors on osx)
-        if MMAP_SUPPORTED and POSIX and not is_Wayland():
+        if POSIX and not is_Wayland():
             #we may be running inside another server!
             try:
                 from xpra.server.server_uuid import get_uuid
@@ -366,6 +369,7 @@ class UIXpraClient(ClientBaseClass):
             updict(caps, prefix, c, flatten_dicts=False)
         u("control_commands",   self.get_control_commands_caps())
         u("platform",           get_platform_info())
+        u("opengl",             self.opengl_props)
         return caps
 
 
@@ -431,6 +435,16 @@ class UIXpraClient(ClientBaseClass):
         log.info("Xpra %s server version %s %i-bit", mode, std(r), bits)
         if i:
             log.info(" running on %s", std(i))
+        if c.boolget("desktop") or c.boolget("shadow"):
+            v = c.intpair("actual_desktop_size")
+            if v:
+                w, h = v
+                ss = c.listget("screen_sizes")
+                if ss:
+                    log.info(" remote desktop size is %sx%s with %s screen%s:", w, h, len(ss), engs(ss))
+                    log_screen_sizes(w, h, ss)
+                else:
+                    log.info(" remote desktop size is %sx%s", w, h)
         if c.boolget("proxy"):
             proxy_hostname = c.strget("proxy.hostname")
             proxy_platform = c.strget("proxy.platform")
@@ -480,7 +494,7 @@ class UIXpraClient(ClientBaseClass):
                 log.error("Error processing handshake callback %s", cb, exc_info=True)
 
     def after_handshake(self, cb, *args):
-        log("after_handshake(%s, %s) on_handshake=%s", cb, args, repr_ellipsized(str(self._on_handshake)))
+        log("after_handshake(%s, %s) on_handshake=%s", cb, args, ellipsizer(self._on_handshake))
         if self._on_handshake is None:
             #handshake has already occurred, just call it:
             self.idle_add(cb, *args)
