@@ -1,24 +1,49 @@
-# coding=utf8
+# -*- coding: utf-8 -*-
 # This file is part of Xpra.
-# Copyright (C) 2012-2014 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2012-2019 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
 import weakref
-from xpra.log import Logger
-log = Logger("util")
+
+
+#note: this is just for defining the order of encodings,
+#so we have both core encodings (rgb24/rgb32) and regular encodings (rgb) in here:
+PREFERED_ENCODING_ORDER = (
+    "h264", "vp9", "vp8", "mpeg4",
+    "mpeg4+mp4", "h264+mp4", "vp8+webm", "vp9+webm",
+    "png", "png/P", "png/L", "webp",
+    "rgb", "rgb24", "rgb32", "jpeg",
+    "h265", "mpeg1", "mpeg2",
+    )
+#encoding order for edges (usually one pixel high or wide):
+EDGE_ENCODING_ORDER = (
+    "rgb24", "rgb32",
+    "png", "webp",
+    "png/P", "png/L", "rgb", "jpeg",
+    )
+
+HELP_ORDER = (
+    "auto", "h264", "h265", "vp8", "vp9", "mpeg4",
+    "png", "png/P", "png/L", "webp",
+    "rgb", "jpeg",
+    )
+
+#those are currently so useless that we don't want the user to select them by mistake
+PROBLEMATIC_ENCODINGS = ("h265", )
 
 
 #value: how much smaller the output is
-LOSSY_PIXEL_FORMATS = {"YUV420P" : 2,
-                       "YUV422P" : 1.5
-                       }
+LOSSY_PIXEL_FORMATS = {
+    "YUV420P" : 2,
+    "YUV422P" : 1.5,
+    }
 
 PIXEL_SUBSAMPLING = {
-         "YUV420P"   : ((1, 1), (2, 2), (2, 2)),
-         "YUV422P"   : ((1, 1), (2, 1), (2, 1)),
-         "YUV444P"   : ((1, 1), (1, 1), (1, 1)),
-         "GBRP"      : ((1, 1), (1, 1), (1, 1)),
+    "YUV420P"   : ((1, 1), (2, 2), (2, 2)),
+    "YUV422P"   : ((1, 1), (2, 1), (2, 1)),
+    "YUV444P"   : ((1, 1), (1, 1), (1, 1)),
+    "GBRP"      : ((1, 1), (1, 1), (1, 1)),
 }
 def get_subsampling_divs(pixel_format):
     # Return size dividers for the given pixel format
@@ -90,11 +115,15 @@ class _codec_spec(object):
 
 
     def make_instance(self):
+        from xpra.log import Logger
+        log = Logger("encoding")
         cur = self.get_instance_count()
         if (self.max_instances>0 and cur>=self.max_instances) or cur>=_codec_spec.WARN_LIMIT:
-            log.warn("Warning: already %s active instances of %s: %s", cur, self.codec_class, list(self.instances.keys()))
+            instances = tuple(self.instances.keys())
+            log.warn("Warning: already %s active instances of %s: %s",
+                     cur, self.codec_class, instances)
             from xpra.util import dump_references
-            dump_references(log, self.instances.keys())
+            dump_references(log, instances)
         else:
             log("make_instance() %s - instance count=%s", self.codec_type, cur)
         v = self.codec_class()
@@ -103,7 +132,7 @@ class _codec_spec(object):
 
 
     def get_instance_count(self):
-        return len(list(self.instances.keys()))
+        return len(self.instances)
 
     def to_dict(self):
         d = {}
@@ -115,7 +144,7 @@ class _codec_spec(object):
         #a cost multiplier that some encoder may want to override
         #1.0 means no change:
         mi = self.max_instances
-        ic = len(self.instances.keys())
+        ic = len(self.instances)
         if ic==0 or mi==0:
             return 1.0                      #no problem
         if ic>=mi:
@@ -125,54 +154,40 @@ class _codec_spec(object):
             return max(0, 1.0 - (1.0*ic/mi)**2)
         return 1.0
 
-    def info(self):
-        try:
-            s = str(self.codec_class)
-            #regexp it?
-            p = s.find("xpra.codecs.")
-            if p>=0:
-                s = s[p+len("xpra.codecs."):]
-            p = s.find(".encoder.")
-            if p<0:
-                p = s.find(".colorspace_converter.")
-            if p>0:
-                s = s[:p]
-            if s=="csc_%s" % self.codec_type:
-                return self.codec_type
-            if s=="enc_%s" % self.codec_type:
-                return self.codec_type
-            if self.codec_type==s:
-                return self.codec_type
-            if s.startswith(self.codec_type):
-                return s
-            return "%s:%s" % (self.codec_type, s)
-        except:
-            return "%s" % (self.codec_type or self.codec_class)
-
 
 class video_spec(_codec_spec):
 
-    def __init__(self, encoding=None, output_colorspaces=None, has_lossless_mode=False, **kwargs):
-        _codec_spec.__init__(self, **kwargs)
+    def __init__(self, encoding, input_colorspace, output_colorspaces, has_lossless_mode,
+                 codec_class, codec_type, **kwargs):
         self.encoding = encoding                        #ie: "h264"
+        self.input_colorspace = input_colorspace
         self.output_colorspaces = output_colorspaces    #ie: ["YUV420P" : "YUV420P", ...]
         self.has_lossless_mode = has_lossless_mode
-        self._exported_fields += ["encoding", "output_colorspaces"]
+        _codec_spec.__init__(self, codec_class, codec_type, **kwargs)
+        self._exported_fields += ["encoding", "input_colorspace", "output_colorspaces", "has_lossless_mode"]
 
     def __repr__(self):
-        return "video_spec(%s)" % self.info()
+        return "%s(%s to %s)" % (self.codec_type, self.input_colorspace, self.encoding)
 
 
 class csc_spec(_codec_spec):
 
+    def __init__(self, input_colorspace, output_colorspace, codec_class, codec_type, **kwargs):
+        self.input_colorspace = input_colorspace
+        self.output_colorspace = output_colorspace
+        _codec_spec.__init__(self, codec_class, codec_type, **kwargs)
+        self._exported_fields += ["input_colorspace", "output_colorspace"]
+
     def __repr__(self):
-        return "video_spec(%s)" % self.info()
+        return "%s(%s to %s)" % (self.codec_type, self.input_colorspace, self.output_colorspace)
 
 
 def main():
     from xpra.platform import program_context
     with program_context("Codec-Constants", "Codec Constants Info"):
         import sys
+        from xpra.log import Logger
+        log = Logger("encoding")
         if "-v" in sys.argv or "--verbose" in sys.argv:
             log.enable_debug()
         log.info("LOSSY_PIXEL_FORMATS=%s", LOSSY_PIXEL_FORMATS)
