@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # This file is part of Xpra.
-# Copyright (C) 2013-2017 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2013-2020 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -8,7 +8,7 @@ import sys
 import os
 
 from xpra.util import pver, print_nested_dict, engs, envbool, csv
-from xpra.os_util import bytestostr, strtobytes
+from xpra.os_util import bytestostr, strtobytes, POSIX
 from xpra.log import Logger
 
 log = Logger("encoder", "util")
@@ -51,6 +51,8 @@ def get_nvml_driver_version():
 
 
 def get_proc_driver_version():
+    if not POSIX:
+        return ()
     from xpra.os_util import load_binary_file
     proc_file = "/proc/driver/nvidia/version"
     v = load_binary_file(proc_file)
