@@ -56,7 +56,7 @@ else:
     def verify_main_thread():
         ct = threading.current_thread()
         if main_thread != ct:
-            log.error("Error: invalid access from thread %s", ct)
+            log.error("Error: invalid access from thread %s", threading.current_thread())
             traceback.print_stack()
     verify_main_thread()
 
