@@ -7,7 +7,7 @@
 import os.path
 import array
 
-from xpra.util import iround, first_time, envint
+from xpra.util import iround, first_time, envint, envbool
 from xpra.os_util import (
     strtobytes, bytestostr,
     WIN32, OSX, PYTHON2, POSIX,
@@ -283,6 +283,7 @@ if is_gtk3():
     SUBSTRUCTURE_MASK    = gdk.EventMask.SUBSTRUCTURE_MASK
     STRUCTURE_MASK       = gdk.EventMask.STRUCTURE_MASK
     EXPOSURE_MASK        = gdk.EventMask.EXPOSURE_MASK
+    SMOOTH_SCROLL_MASK   = gdk.EventMask.SMOOTH_SCROLL_MASK
     ACCEL_LOCKED = gtk.AccelFlags.LOCKED
     ACCEL_VISIBLE = gtk.AccelFlags.VISIBLE
     JUSTIFY_LEFT    = gtk.Justification.LEFT
@@ -353,6 +354,9 @@ if is_gtk3():
     WINDOW_EVENT_MASK = em.STRUCTURE_MASK | em.KEY_PRESS_MASK | em.KEY_RELEASE_MASK \
             | em.POINTER_MOTION_MASK | em.BUTTON_PRESS_MASK | em.BUTTON_RELEASE_MASK \
             | em.PROPERTY_CHANGE_MASK | em.SCROLL_MASK
+    SMOOTH_SCROLL = envbool("XPRA_SMOOTH_SCROLL", True)
+    if SMOOTH_SCROLL:
+        WINDOW_EVENT_MASK |= em.SMOOTH_SCROLL_MASK
     del em
 
     WINDOW_NAME_TO_HINT = {
@@ -584,6 +588,7 @@ else:
     SUBSTRUCTURE_MASK    = gdk.SUBSTRUCTURE_MASK
     STRUCTURE_MASK       = gdk.STRUCTURE_MASK
     EXPOSURE_MASK        = gdk.EXPOSURE_MASK
+    SMOOTH_SCROLL_MASK   = 0
     ACCEL_LOCKED = gtk.ACCEL_LOCKED
     ACCEL_VISIBLE = gtk.ACCEL_VISIBLE
     JUSTIFY_LEFT    = gtk.JUSTIFY_LEFT
