@@ -146,7 +146,8 @@ def do_get_bind_ifacemask(iface):
                         socket.inet_aton(addr)
                         ipmasks.append((addr,mask))
                     except Exception as e:
-                        log.error("do_get_bind_ifacemask(%s) error on %s", iface, addr, e)
+                        log("do_get_bind_ifacemask(%s)", iface, exc_info=True)
+                        log.error("Error converting address '%s' to binary, for interface %s", addr, iface)
     log("do_get_bind_ifacemask(%s)=%s", iface, ipmasks)
     return ipmasks
 
@@ -385,10 +386,6 @@ def get_ssl_info(show_constants=False):
 
 
 def get_network_caps():
-    try:
-        from xpra.platform.features import MMAP_SUPPORTED
-    except ImportError:
-        MMAP_SUPPORTED = False
     from xpra.net.digest import get_digests
     from xpra.net.crypto import get_crypto_caps
     from xpra.net.compression import get_enabled_compressors, get_compression_caps
@@ -401,7 +398,6 @@ def get_network_caps():
                 "salt-digest"           : salt_digests,
                 "compressors"           : get_enabled_compressors(),
                 "encoders"              : get_enabled_encoders(),
-                "mmap"                  : MMAP_SUPPORTED,
                }
     caps.update(get_crypto_caps())
     caps.update(get_compression_caps())
