@@ -1,5 +1,5 @@
 # This file is part of Xpra.
-# Copyright (C) 2017-2019 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2017-2020 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -9,14 +9,14 @@ from time import sleep
 
 from xpra.scripts.config import InitException, TRUE_OPTIONS
 from xpra.os_util import (
-    bytestostr, hexstr,
+    hexstr,
     getuid, get_username_for_uid, get_groups, get_group_id,
     path_permission_info, monotonic_time, umask_context, WIN32, OSX, POSIX,
     )
 from xpra.net.bytestreams import set_socket_timeout
 from xpra.util import (
     envint, envbool, csv,
-    repr_ellipsized,
+    repr_ellipsized, ellipsizer,
     DEFAULT_PORT,
     )
 
@@ -189,9 +189,9 @@ def peek_connection(conn, timeout=PEEK_TIMEOUT_MS):
     set_socket_timeout(conn, PEEK_TIMEOUT_MS*1000)
     if peek_data:
         line1 = peek_data.splitlines()[0]
-        log("socket peek=%s", repr_ellipsized(peek_data, limit=512))
+        log("socket peek=%s", ellipsizer(peek_data, limit=512))
         log("socket peek hex=%s", hexstr(peek_data[:128]))
-        log("socket peek line1=%s", repr_ellipsized(bytestostr(line1)))
+        log("socket peek line1=%s", ellipsizer(line1))
     return peek_data, line1
 
 
@@ -601,7 +601,7 @@ def handle_socket_error(sockpath, sperms, e):
             log.info(" %s does not exist", dirname)
         #only show extra information if the socket permissions
         #would have been accessible by the group:
-        if POSIX and (sperms & 0o40):
+        elif POSIX and (sperms & 0o40):
             uid = getuid()
             username = get_username_for_uid(uid)
             groups = get_groups(username)
