@@ -1,12 +1,14 @@
 # This file is part of Xpra.
-# Copyright (C) 2011-2018 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2011-2018 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
 import sys
 import os.path
+
 from xpra.util import envbool, get_util_logger
 
+
 def debug(*msg):
     """ delay import of logger to prevent cycles """
     log = get_util_logger()
@@ -80,7 +82,11 @@ def do_get_system_conf_dirs():
     #the system wide configuration directory
     dirs = []
     try:
-        from Foundation import  NSSearchPathForDirectoriesInDomains, NSApplicationSupportDirectory, NSLocalDomainMask, NSSystemDomainMask  #@UnresolvedImport
+        from Foundation import (
+            NSSearchPathForDirectoriesInDomains,    #@UnresolvedImport
+            NSApplicationSupportDirectory,          #@UnresolvedImport
+            NSLocalDomainMask, NSSystemDomainMask   #@UnresolvedImport
+            )
         sdirs = NSSearchPathForDirectoriesInDomains(NSApplicationSupportDirectory, NSLocalDomainMask|NSSystemDomainMask, False)
         for x in sdirs:
             #ie: "/Library/Application Support/Xpra"
@@ -114,7 +120,9 @@ def do_get_user_conf_dirs(_uid):
 def do_get_default_log_dirs():
     dirs = []
     try:
-        from Foundation import  NSSearchPathForDirectoriesInDomains, NSLibraryDirectory, NSUserDomainMask    #@UnresolvedImport
+        from Foundation import (
+            NSSearchPathForDirectoriesInDomains, NSLibraryDirectory, NSUserDomainMask,  #@UnresolvedImport
+            )
         udirs = NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSUserDomainMask, False)
         for x in udirs:
             #ie: ~/Library/
@@ -131,7 +139,9 @@ def do_get_socket_dirs():
 def do_get_download_dir():
     d = "~/Downloads"
     try:
-        from Foundation import  NSSearchPathForDirectoriesInDomains, NSDownloadsDirectory, NSUserDomainMask     #@UnresolvedImport
+        from Foundation import (
+            NSSearchPathForDirectoriesInDomains, NSDownloadsDirectory, NSUserDomainMask,    #@UnresolvedImport
+            )
         d = NSSearchPathForDirectoriesInDomains(NSDownloadsDirectory, NSUserDomainMask, False)[0]
         #(should be "~/Downloads")
     except:
@@ -141,6 +151,13 @@ def do_get_download_dir():
     return d
 
 
+def do_get_desktop_background_paths():
+    return [
+        "/System/Library/CoreServices/DefaultDesktop.jpg",
+        "/Library/Desktop Pictures/*jpg",
+        ]
+
+
 def do_get_libexec_dir():
     from xpra.platform.paths import get_app_dir
     base = get_app_dir()
@@ -178,6 +195,11 @@ def do_get_nodock_command():
     helper = os.path.join(base, "Resources", "scripts", "Xpra")
     if not os.path.exists(helper):
         helper = os.path.join(base, "Helpers", "Xpra")
+    if not os.path.exists(helper):
+        #having a dock is still better than
+        #trying to run a command that does not exist!
+        from xpra.platform.paths import get_xpra_command
+        return get_xpra_command()
     return [helper]
 
 def do_get_sound_command():
