@@ -1,6 +1,6 @@
 # This file is part of Xpra.
 # Copyright (C) 2010 Nathaniel Smith <njs@pobox.com>
-# Copyright (C) 2011-2014 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2011-2014 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -27,6 +27,35 @@ class KeyboardBase(object):
     def has_bell(self):
         return False
 
+    def _add_modifier_mapping(self, a, b, modifier):
+        #log.info("%s (%s), %s (%s)", keycode, type(keycode), keyname, type(keyname))
+        if isinstance(a, int) and isinstance(b, (bytes, str)):
+            self._do_add_modifier_mapping((b,), a, modifier)
+        elif isinstance(a, (str,bytes)) and isinstance(b, int):
+            #level = b
+            self._do_add_modifier_mapping((a,), 0, modifier)
+        elif isinstance(a, (bytes,str)) and isinstance(b, (bytes,str)):
+            self._do_add_modifier_mapping((a, b), 0, modifier)
+        elif isinstance(a, (tuple,list)) and isinstance(b, (bytes,str)):
+            #ie: a=(57, 'CapsLock'), b='CapsLock'
+            if len(a)==2:
+                self._add_modifier_mapping(a[0], a[1], modifier)
+            self._add_modifier_mapping((b,), 0, modifier)
+        elif isinstance(a, (tuple,list)) and isinstance(b, (int)):
+            #ie: a=('CapsLock'), b=0
+            self._do_add_modifier_mapping(a, 0, modifier)
+        else:
+            log.warn("Warning: unexpected key definition: %s, %s", type(a), type(b))
+            log.warn(" values: %s, %s", a, b)
+
+    def _do_add_modifier_mapping(self, keynames, keycode, modifier):
+        for keyname in keynames:
+            self.modifier_keys[bytestostr(keyname)] = bytestostr(modifier)
+            if keycode:
+                keycodes = self.modifier_keycodes.setdefault(bytestostr(keyname), [])
+                if keycode not in keycodes:
+                    keycodes.append(keycode)
+
     def set_modifier_mappings(self, mappings):
         log("set_modifier_mappings(%s)", mappings)
         self.modifier_mappings = mappings
@@ -34,20 +63,7 @@ class KeyboardBase(object):
         self.modifier_keycodes = {}
         for modifier, keys in mappings.items():
             for a, b in keys:
-                #log.info("%s (%s), %s (%s)", keycode, type(keycode), keyname, type(keyname))
-                if isinstance(a, int) and isinstance(b, bytes):
-                    keycode = a
-                    keyname = b
-                elif isinstance(a, bytes) and isinstance(b, int):
-                    keyname = a
-                    #level = b
-                    keycode = 0
-                self.modifier_keys[bytestostr(keyname)] = bytestostr(modifier)
-                if keycode:
-                    keycodes = self.modifier_keycodes.setdefault(bytestostr(keyname), [])
-                    if keycode not in keycodes:
-                        keycodes.append(keycode)
-                self.modifier_keys[bytestostr(keyname)] = bytestostr(modifier)
+                self._add_modifier_mapping(a, b, modifier)
         log("modifier_keys=%s", self.modifier_keys)
         log("modifier_keycodes=%s", self.modifier_keycodes)
 
