@@ -23,6 +23,7 @@ from ctypes.wintypes import (
 #imported from this module but not used here:
 assert GetLastError
 
+LPMSG = POINTER(MSG)
 LPCTSTR = LPCSTR
 LRESULT = c_long
 DEVMODE = c_void_p
@@ -32,7 +33,6 @@ PBYTE = POINTER(BYTE)
 HCURSOR = HANDLE
 HICON = HANDLE
 HBRUSH = HANDLE
-LPMSG = POINTER(MSG)
 
 class CURSORINFO(Structure):
     _fields_ = [
@@ -176,6 +176,9 @@ GetModuleHandleA = kernel32.GetModuleHandleA
 GetModuleHandleA.restype = HMODULE
 GetModuleHandleW = kernel32.GetModuleHandleW
 GetModuleHandleW.restype = HMODULE
+GetModuleHandleExA  = kernel32.GetModuleHandleExA
+GetModuleHandleExA.argtypes = [DWORD, LPCSTR, POINTER(HMODULE)]
+GetModuleHandleExA.restype = BOOL
 ConsoleCtrlHandler = WINFUNCTYPE(BOOL, DWORD)
 SetConsoleCtrlHandler = kernel32.SetConsoleCtrlHandler
 SetConsoleCtrlHandler.argtypes = (ConsoleCtrlHandler, BOOL)
