@@ -21,7 +21,7 @@ log = Logger("exec", "menu")
 
 LOAD_GLOB = envbool("XPRA_XDG_LOAD_GLOB", True)
 EXPORT_ICONS = envbool("XPRA_XDG_EXPORT_ICONS", True)
-MAX_ICON_SIZE = envint("XPRA_XDG_MAX_ICON_SIZE", 65536)
+MAX_ICON_SIZE = envint("XPRA_XDG_MAX_ICON_SIZE", 0)
 DEBUG_COMMANDS = os.environ.get("XPRA_XDG_DEBUG_COMMANDS", "").split(",")
 if PYTHON3:
     unicode = str           #@ReservedAssignment
@@ -106,8 +106,37 @@ def load_icon_from_file(filename):
     icondata = load_binary_file(filename)
     if not icondata:
         return None
+    if filename.endswith("svg") and len(icondata)>MAX_ICON_SIZE//2:
+        #try to resize it
+        try:
+            size = len(icondata)
+            import cairo
+            import gi
+            try:
+                gi.require_version('Rsvg', '2.0')
+            except ValueError as e:
+                if first_time("no-rsvg"):
+                    log.warn("Warning: cannot resize svg icons, Rsvg bindings not found:")
+                    log.warn(" %s", e)
+            else:
+                from gi.repository import Rsvg
+                img = cairo.ImageSurface(cairo.FORMAT_ARGB32, 128, 128)
+                ctx = cairo.Context(img)
+                handle = Rsvg.Handle.new_from_data(icondata)
+                handle.render_cairo(ctx)
+                buf = BytesIO()
+                img.write_to_png(buf)
+                icondata = buf.getvalue()
+                buf.close()
+                log("reduced size of SVG icon %s, from %i bytes to %i bytes as PNG",
+                         filename, size, len(icondata))
+                filename = filename[:-3]+"png"
+        except ImportError:
+            log("cannot convert svg", exc_info=True)
+        except Exception:
+            log.error("Error: failed to convert svg icon", exc_info=True)
     log("got icon data from '%s': %i bytes", filename, len(icondata))
-    if len(icondata)>MAX_ICON_SIZE and first_time("icon-size-warning-%s" % filename):
+    if MAX_ICON_SIZE>0 and len(icondata)>MAX_ICON_SIZE and first_time("icon-size-warning-%s" % filename):
         log.warn("Warning: icon is quite large (%i KB):", len(icondata)//1024)
         log.warn(" '%s'", filename)
     return icondata, os.path.splitext(filename)[1].lstrip(".")
@@ -271,6 +300,8 @@ def do_load_xdg_menu_data():
                     log("do_load_xdg_menu_data()", exc_info=True)
                     error = e
                     menu = None
+            if menu:
+                break
     if menu is None:
         if error:
             log.error("Error parsing xdg menu data:")
