@@ -1,41 +1,41 @@
 #!/usr/bin/env python
 # This file is part of Xpra.
-# Copyright (C) 2015 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2015-2020 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-import signal, sys
+import sys
 
-def main():
+
+def main(argv=()):
+    from xpra.os_util import POSIX, OSX
     from xpra.platform import program_context
+    from xpra.platform.gui import init, set_default_icon
     with program_context("Xpra-Bug-Report", "Xpra Bug Report"):
         from xpra.log import enable_color
         enable_color()
 
-        from xpra.log import Logger, enable_debug_for
-        log = Logger("util")
+        set_default_icon("bugs.png")
+        init()
+
+        if POSIX and not OSX:
+            from xpra.x11.gtk_x11.gdk_display_source import init_gdk_display_source
+            init_gdk_display_source()
+
+        from xpra.log import enable_debug_for
         #logging init:
-        if "-v" in sys.argv:
+        if "-v" in argv:
             enable_debug_for("util")
 
-        from xpra.gtk_common.gobject_compat import import_gobject
-        gobject = import_gobject()
-        gobject.threads_init()
-
-        from xpra.os_util import SIGNAMES
         from xpra.gtk_common.quit import gtk_main_quit_on_fatal_exceptions_enable
         gtk_main_quit_on_fatal_exceptions_enable()
 
         from xpra.client.gtk_base.bug_report import BugReport
+        from xpra.gtk_common.gobject_compat import register_os_signals
         app = BugReport()
         app.close = app.quit
         app.init(True)
-        def app_signal(signum, _frame):
-            print("")
-            log.info("got signal %s", SIGNAMES.get(signum, signum))
-            app.quit()
-        signal.signal(signal.SIGINT, app_signal)
-        signal.signal(signal.SIGTERM, app_signal)
+        register_os_signals(app.quit)
         try:
             from xpra.platform.gui import ready as gui_ready
             gui_ready()
@@ -47,5 +47,5 @@ def main():
 
 
 if __name__ == "__main__":
-    v = main()
+    v = main(sys.argv)
     sys.exit(v)
