@@ -577,7 +577,7 @@ OPTION_TYPES = {
                     "attach"            : bool,
                     "use-display"       : bool,
                     "fake-xinerama"     : str,
-                    "resize_display"    : bool,
+                    "resize-display"    : bool,
                     "tray"              : bool,
                     "pulseaudio"        : bool,
                     "dbus-proxy"        : bool,
@@ -623,6 +623,8 @@ OPTION_TYPES = {
                     "compressors"       : list,
                     "packet-encoders"   : list,
                     "key-shortcut"      : list,
+                    "source"            : list,
+                    "source-start"      : list,
                     "start"             : list,
                     "start-child"       : list,
                     "start-after-connect"       : list,
@@ -683,6 +685,7 @@ OPTIONS_ADDED_SINCE_V1 = [
     "uid", "gid", "chdir", "min-port", "rfb-upgrade", "bandwidth-limit",
     "forward-xdg-open", "modal-windows", "bandwidth-detection",
     "bind-ssh", "ssh-auth", "ssh-upgrade",
+    "source", "source-start",
     ]
 OPTIONS_COMPAT_NAMES = {
     "--compression_level=" : "-z"
@@ -723,7 +726,9 @@ CLIENT_OPTIONS = ["title", "username", "password", "session-name",
                   "env"]
 
 CLIENT_ONLY_OPTIONS = ["username", "swap-keys", "dock-icon",
-                       "tray", "delay-tray", "tray-icon"]
+                       "tray", "delay-tray", "tray-icon",
+                       "attach",
+                       ]
 
 #options that clients can pass to the proxy
 #and which will be forwarded to the new proxy instance process:
@@ -741,7 +746,7 @@ PROXY_START_OVERRIDABLE_OPTIONS = [
     "input-method",
     "microphone", "speaker", "sound-source", "pulseaudio",
     "idle-timeout", "server-idle-timeout",
-    "use-display", "fake-xinerama", "resize_display", "dpi", "pixel-depth",
+    "use-display", "fake-xinerama", "resize-display", "dpi", "pixel-depth",
     "readonly", "keyboard-sync", "cursors", "bell", "notifications", "xsettings",
     "system-tray", "sharing", "lock", "windows", "webcam", "html",
     "terminate-children", "exit-with-children", "exit-with-client",
@@ -753,7 +758,7 @@ PROXY_START_OVERRIDABLE_OPTIONS = [
     "auth", "vsock-auth", "tcp-auth", "udp-auth", "ws-auth", "wss-auth", "ssl-auth", "ssh-auth", "rfb-auth",
     "bind", "bind-vsock", "bind-tcp", "bind-udp", "bind-ssl", "bind-ws", "bind-wss", "bind-ssh", "bind-rfb",
     "rfb-upgrade", "bandwidth-limit",
-    "start", "start-child",
+    "start", "start-child", "source", "source-start",
     "start-after-connect", "start-child-after-connect",
     "start-on-connect", "start-child-on-connect",
     "start-on-last-client-exit", "start-child-on-last-client-exit",
@@ -798,15 +803,11 @@ def get_default_key_shortcuts():
 def get_default_systemd_run():
     if WIN32 or OSX:
         return "no"
-    #don't use systemd-run on CentOS / RedHat
-    #(it causes failures with "Failed to create bus connection: No such file or directory")
-    if is_CentOS() or is_RedHat():
-        return "no"
-    if is_Fedora():
-        return "no"
     #systemd-run was previously broken in Fedora 26:
     #https://github.com/systemd/systemd/issues/3388
     #but with newer kernels, it is working again..
+    #now that we test it before using it,
+    #it should be safe to leave it on auto:
     return "auto"
 
 def get_default_pulseaudio_command():
@@ -963,7 +964,7 @@ def get_defaults():
                     "ssl-client-verify-mode"   : "optional",
                     "ssl-server-verify-mode"   : "required",
                     "ssl-verify-flags"  : "X509_STRICT",
-                    "ssl-check-hostname": False,
+                    "ssl-check-hostname": True,
                     "ssl-server-hostname": "",
                     "ssl-options"       : "ALL,NO_COMPRESSION",
                     "quality"           : 0,
@@ -1058,6 +1059,8 @@ def get_defaults():
                     "ssh-auth"          : [],
                     "rfb-auth"          : [],
                     "password-file"     : [],
+                    "source"            : [],
+                    "source-start"      : [],
                     "start"             : [],
                     "start-child"       : [],
                     "start-after-connect"       : [],
