@@ -124,6 +124,9 @@ def display_name_check(display_name):
     n = display_name[1:].split(".")[0]    #ie: ":0.0" -> "0"
     try:
         dno = int(n)
+    except (ValueError, TypeError):
+        raise InitException("invalid display number %r" % n)
+    else:
         if 0<=dno<10:
             warn("WARNING: low display number: %s" % dno)
             warn(" You are attempting to run the xpra server")
@@ -131,8 +134,6 @@ def display_name_check(display_name):
             warn(" This is generally not what you want.")
             warn(" You should probably use a higher display number")
             warn(" just to avoid any confusion and this warning message.")
-    except IOError:
-        pass
 
 
 def print_DE_warnings():
@@ -373,7 +374,7 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
     upgrading_desktop = mode == "upgrade-desktop"
     shadowing = mode == "shadow"
     proxying  = mode == "proxy"
-    clobber   = int(upgrading or upgrading_desktop) | int(opts.use_display or 0)*2
+    clobber   = int(upgrading or upgrading_desktop) | int(opts.use_display)*2
     start_vfb = not (shadowing or proxying or clobber)
 
     if not proxying and PYTHON3 and POSIX and not OSX:
@@ -383,11 +384,17 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
         saved_env["GDK_BACKEND"] = "x11"
         os.environ["GDK_BACKEND"] = "x11"
 
+    has_child_arg = (
+            opts.start_child or
+            opts.start_child_on_connect or
+            opts.start_child_after_connect or
+            opts.start_child_on_last_client_exit
+            )
     if proxying or upgrading or upgrading_desktop:
         #when proxying or upgrading, don't exec any plain start commands:
         opts.start = opts.start_child = []
     elif opts.exit_with_children:
-        assert opts.start_child, "exit-with-children was specified but start-child is missing!"
+        assert has_child_arg, "exit-with-children was specified but start-child* is missing!"
     elif opts.start_child:
         warn("Warning: the 'start-child' option is used,")
         warn(" but 'exit-with-children' is not enabled,")
@@ -420,7 +427,7 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
             error_cb("too many extra arguments (%i): only expected a display number" % len(extra_args))
         if len(extra_args) == 1:
             display_name = extra_args[0]
-            if not shadowing and not proxying and not upgrading and not opts.use_display:
+            if not shadowing and not proxying and not opts.use_display:
                 display_name_check(display_name)
         else:
             if proxying:
@@ -446,7 +453,7 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
                 display_name = 'S' + str(os.getpid())
 
     if not (shadowing or proxying or upgrading or upgrading_desktop) and \
-    opts.exit_with_children and not opts.start_child:
+    opts.exit_with_children and not has_child_arg:
         error_cb("--exit-with-children specified without any children to spawn; exiting immediately")
 
     atexit.register(run_cleanups)
@@ -458,6 +465,7 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
         write_runner_shell_scripts,
         find_log_dir,
         create_input_devices,
+        source_env,
         )
     script = None
     if POSIX and getuid()!=0:
@@ -561,6 +569,8 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
         # environment:
         write_runner_shell_scripts(script)
 
+    import datetime
+    extra_expand = {"TIMESTAMP" : datetime.datetime.now().strftime("%Y%m%d-%H%M%S")}
     if start_vfb or opts.daemon:
         #we will probably need a log dir
         #either for the vfb, or for our own log file
@@ -576,7 +586,8 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
 
         if opts.daemon:
             from xpra.server.server_util import select_log_file, open_log_file, redirect_std_to_log
-            log_filename0 = osexpand(select_log_file(log_dir, opts.log_file, display_name), username, uid, gid)
+            log_filename0 = osexpand(select_log_file(log_dir, opts.log_file, display_name),
+                                     username, uid, gid, extra_expand)
             logfd = open_log_file(log_filename0)
             if ROOT and (uid>0 or gid>0):
                 try:
@@ -588,9 +599,11 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
                 stderr.write("Entering daemon mode; "
                          + "any further errors will be reported to:\n"
                          + ("  %s\n" % log_filename0))
+                stderr.flush()
             except IOError:
                 #we tried our best, logging another error won't help
                 pass
+            os.environ["XPRA_SERVER_LOG"] = log_filename0
 
     #warn early about this:
     if (starting or starting_desktop) and desktop_display and opts.notifications and not opts.dbus_launch:
@@ -600,6 +613,7 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
     sockets = create_sockets(opts, error_cb)
 
     sanitize_env()
+    os.environ.update(source_env(opts.source))
     if POSIX:
         if xrd:
             os.environ["XDG_RUNTIME_DIR"] = xrd
@@ -685,10 +699,16 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
                 fn(*args)
             except Exception:
                 pass
-        log_filename1 = osexpand(select_log_file(log_dir, opts.log_file, display_name), username, uid, gid)
+        log_filename1 = osexpand(select_log_file(log_dir, opts.log_file, display_name),
+                                 username, uid, gid, extra_expand)
         if log_filename0 != log_filename1:
             # we now have the correct log filename, so use it:
-            os.rename(log_filename0, log_filename1)
+            try:
+                os.rename(log_filename0, log_filename1)
+            except (OSError, IOError):
+                pass
+            else:
+                os.environ["XPRA_SERVER_LOG"] = log_filename1
             if odisplay_name!=display_name:
                 #this may be used by scripts, let's try not to change it:
                 noerr(stderr.write, "Actual display used: %s\n" % display_name)
@@ -696,6 +716,12 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
             noerr(stderr.flush)
         noerr(stdout.close)
         noerr(stderr.close)
+    else:
+        #server log does not exist:
+        try:
+            del os.environ["XPRA_SERVER_LOG"]
+        except KeyError:
+            pass
     #we should not be using stdout or stderr from this point:
     del stdout
     del stderr
