@@ -1,5 +1,5 @@
 # This file is part of Xpra.
-# Copyright (C) 2014-2017 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2014-2017 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -17,13 +17,13 @@ class Authenticator(SysAuthenticator):
     def requires_challenge(self):
         return False
 
-    def get_challenge(self, digests):
+    def get_challenge(self, _digests):
         return None
 
     def get_password(self):
         return None
 
-    def authenticate(self, challenge_response, client_salt):
+    def authenticate(self, _challenge_response=None, _client_salt=None):
         return True
 
     def __repr__(self):
