@@ -12,6 +12,7 @@ from xpra.child_reaper import getChildReaper, reaper_cleanup
 from xpra.os_util import monotonic_time, bytestostr, OSX, WIN32, POSIX
 from xpra.util import envint, csv
 from xpra.scripts.parsing import parse_env
+from xpra.server.server_util import source_env
 from xpra.server import EXITING_CODE
 from xpra.server.mixins.stub_server_mixin import StubServerMixin
 from xpra.log import Logger
@@ -39,9 +40,11 @@ class ChildCommandServer(StubServerMixin):
         self.start_on_last_client_exit = []
         self.start_child_on_last_client_exit = []
         self.exit_with_children = False
+        self.children_count = 0
         self.start_after_connect_done = False
         self.start_new_commands = False
-        self.start_env = []
+        self.source_env = {}
+        self.start_env = {}
         self.exec_cwd = None
         self.exec_wrapper = None
         self.terminate_children = False
@@ -73,6 +76,7 @@ class ChildCommandServer(StubServerMixin):
             import shlex
             self.exec_wrapper = shlex.split(opts.exec_wrapper)
         self.child_reaper = getChildReaper()
+        self.source_env = source_env(opts.source_start)
         self.start_env = parse_env(opts.start_env)
 
     def threaded_setup(self):
@@ -111,7 +115,7 @@ class ChildCommandServer(StubServerMixin):
         handler = EventHandler()
         self.watch_notifier = pyinotify.ThreadedNotifier(self.watch_manager, handler)
         self.watch_notifier.setDaemon(True)
-        data_dirs = os.environ.get("XDG_DATA_DIRS", "/usr/share/applications:/usr/local/share/applications").split(":")
+        data_dirs = os.environ.get("XDG_DATA_DIRS", "/usr/share:/usr/local/share").split(":")
         watched = []
         for data_dir in data_dirs:
             menu_dir = os.path.join(data_dir, "applications")
@@ -232,6 +236,7 @@ class ChildCommandServer(StubServerMixin):
     def get_child_env(self):
         #subclasses may add more items (ie: fakexinerama)
         env = os.environ.copy()
+        env.update(self.source_env)
         env.update(self.start_env)
         if self.child_display:
             env["DISPLAY"] = self.child_display
@@ -290,8 +295,9 @@ class ChildCommandServer(StubServerMixin):
             proc = Popen(real_cmd, env=env, shell=shell, cwd=self.exec_cwd, close_fds=True, **kwargs)
             procinfo = self.add_process(proc, name, real_cmd, ignore=ignore, callback=callback)
             log("pid(%s)=%s", real_cmd, proc.pid)
+            log.info("started command '%s' with pid %s", " ".join(real_cmd), proc.pid)
             if not ignore:
-                log.info("started command '%s' with pid %s", " ".join(real_cmd), proc.pid)
+                self.children_count += 1
             self.children_started.append(procinfo)
             return proc
         except (OSError, ValueError) as e:
@@ -309,7 +315,7 @@ class ChildCommandServer(StubServerMixin):
 
     def reaper_exit_check(self):
         log("reaper_exit_check() exit_with_children=%s", self.exit_with_children)
-        if self.exit_with_children:
+        if self.exit_with_children and self.children_count:
             log.info("all children have exited and --exit-with-children was specified, exiting")
             self.idle_add(self.clean_quit)
 
@@ -355,6 +361,13 @@ class ChildCommandServer(StubServerMixin):
             if not proc_info:
                 continue
             cmd = proc_info.command
+            if self.exec_wrapper:
+                #strip exec wrapper
+                l = len(self.exec_wrapper)
+                if len(cmd)>l and cmd[:l]==self.exec_wrapper:
+                    cmd = cmd[l:]
+            elif len(cmd)>1 and cmd[0] in ("vglrun", "nohup",):
+                cmd.pop(0)
             bcmd = os.path.basename(cmd[0])
             if bcmd not in cmd_names:
                 cmd_names.append(bcmd)
