@@ -58,6 +58,8 @@ class ServerBaseControlCommands(StubServerMixin):
 
         for cmd in (
             ArgsControlCommand("focus",                 "give focus to the window id",      validation=[int]),
+            ArgsControlCommand("map",                   "maps the window id",               validation=[int]),
+            ArgsControlCommand("unmap",                 "unmaps the window id",             validation=[int]),
             #window source:
             ArgsControlCommand("suspend",               "suspend screen updates",           max_args=0),
             ArgsControlCommand("resume",                "resume screen updates",            max_args=0),
@@ -93,7 +95,7 @@ class ServerBaseControlCommands(StubServerMixin):
             ArgsControlCommand("scaling",               "set a specific scaling value",     min_args=1, validation=[parse_scaling_value]),
             ArgsControlCommand("auto-refresh",          "set a specific auto-refresh value", min_args=1, validation=[float]),
             ArgsControlCommand("refresh",               "refresh some or all windows",      min_args=0),
-            ArgsControlCommand("encoding",              "picture encoding",                 min_args=1, max_args=1),
+            ArgsControlCommand("encoding",              "picture encoding",                 min_args=2),
             ArgsControlCommand("video-region-enabled",  "enable video region",              min_args=2, max_args=2, validation=[int, parse_boolean_value]),
             ArgsControlCommand("video-region-detection","enable video detection",           min_args=2, max_args=2, validation=[int, parse_boolean_value]),
             ArgsControlCommand("video-region-exclusion-zones","set window regions to exclude from video regions: 'WID,(x,y,w,h),(x,y,w,h),..', ie: '1 (0,10,100,20),(200,300,20,20)'",  min_args=2, max_args=2, validation=[int, parse_4intlist]),
@@ -122,6 +124,44 @@ class ServerBaseControlCommands(StubServerMixin):
         self._focus(None, wid, None)
         return "gave focus to window %s" % wid
 
+    def control_command_map(self, wid):
+        if self.readonly:
+            return
+        assert type(wid)==int, "argument should have been an int, but found %s" % type(wid)
+        window = self._id_to_window.get(wid)
+        assert window, "window %i not found" % wid
+        if window.is_tray():
+            return "cannot map tray window %s" % wid
+        if window.is_OR():
+            return "cannot map override redirect window %s" % wid
+        dm = getattr(self, "_desktop_manager", None)
+        assert dm, "%r does not have a desktop manager" % self
+        dm.show_window(window)
+        #window.set_owner(dm)
+        #iconic = window.get_property("iconic")
+        #if iconic:
+        #    window.set_property("iconic", False)
+        #w, h = window.get_geometry()[2:4]
+        #self.refresh_window_area(window, 0, 0, w, h)
+        self.repaint_root_overlay()
+        return "mapped window %s" % wid
+
+    def control_command_unmap(self, wid):
+        if self.readonly:
+            return
+        assert type(wid)==int, "argument should have been an int, but found %s" % type(wid)
+        window = self._id_to_window.get(wid)
+        assert window, "window %i not found" % wid
+        if window.is_tray():
+            return "cannot map tray window %s" % wid
+        if window.is_OR():
+            return "cannot map override redirect window %s" % wid
+        dm = getattr(self, "_desktop_manager", None)
+        assert dm, "%r does not have a desktop manager" % self
+        dm.hide_window(window)
+        self.repaint_root_overlay()
+        return "unmapped window %s" % wid
+
     def control_command_suspend(self):
         for csource in tuple(self._server_sources.values()):
             csource.suspend(True, self._id_to_window)
@@ -236,8 +276,9 @@ class ServerBaseControlCommands(StubServerMixin):
             raise ControlError("no clients found matching: %s" % client_uuids)
         clients = 0
         for ss in sources:
-            if ss.send_open_url(url):
-                clients += 1
+            if hasattr(ss, "send_open_url"):
+                if ss.send_open_url(url):
+                    clients += 1
         return "url sent to %i clients" % clients
 
     def control_command_send_file(self, filename, openit="open", client_uuids="*", maxbitrate=0):
