@@ -1,5 +1,5 @@
 # This file is part of Xpra.
-# Copyright (C) 2013-2019 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2013-2020 Antoine Martin <antoine@xpra.org>
 # Copyright (C) 2008 Nathaniel Smith <njs@pobox.com>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
@@ -20,7 +20,7 @@ from xpra.os_util import (
     monotonic_time, bytestostr, strtobytes,
     )
 from xpra.util import (
-    flatten_dict, typedict, updict, repr_ellipsized, envint, envbool,
+    flatten_dict, typedict, updict, ellipsizer, envint, envbool,
     csv, first_time, SERVER_SHUTDOWN,
     )
 from xpra.version_util import XPRA_VERSION
@@ -32,11 +32,11 @@ log = Logger("proxy")
 enclog = Logger("encoding")
 
 
-PROXY_QUEUE_SIZE = envint("XPRA_PROXY_QUEUE_SIZE", 10)
+PROXY_QUEUE_SIZE = envint("XPRA_PROXY_QUEUE_SIZE", 0)
 #for testing only: passthrough as RGB:
 PASSTHROUGH_RGB = envbool("XPRA_PROXY_PASSTHROUGH_RGB", False)
 VIDEO_TIMEOUT = 5                  #destroy video encoder after N seconds of idle state
-LEGACY_SALT_DIGEST = envbool("XPRA_LEGACY_SALT_DIGEST", True)
+LEGACY_SALT_DIGEST = envbool("XPRA_LEGACY_SALT_DIGEST", False)
 PASSTHROUGH_AUTH = envbool("XPRA_PASSTHROUGH_AUTH", True)
 
 PING_INTERVAL = max(1, envint("XPRA_PROXY_PING_INTERVAL", 5))*1000
@@ -63,7 +63,7 @@ class ProxyInstance(object):
             session_options,
             video_encoder_modules,
             disp_desc, cipher, encryption_key,
-            "%s: %s.." % (type(caps), repr_ellipsized(str(caps)))))
+            "%s: %s.." % (type(caps), ellipsizer(caps))))
         self.uuid = get_hex_uuid()
         self.client_protocol = None
         self.server_protocol = None
