@@ -1,5 +1,5 @@
 # This file is part of Xpra.
-# Copyright (C) 2017-2019 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2017-2020 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -7,80 +7,162 @@ import sys
 import os.path
 
 from xpra.util import envbool
-from xpra.os_util import OSX, shellsub, getuid, get_util_logger, osexpand, umask_context
+from xpra.os_util import OSX, shellsub, getuid, get_util_logger, osexpand, umask_context, PYTHON3
 from xpra.platform.dotxpra import norm_makepath
 from xpra.scripts.config import InitException
 
 
-def sh_quotemeta(s):
-    return "'" + s.replace("'", "'\\''") + "'"
+def source_env(source=()):
+    log = get_util_logger()
+    env = {}
+    for f in source:
+        e = env_from_sourcing(f)
+        log("source_env %s=%s", f, e)
+        env.update(e)
+    return env
 
-def xpra_runner_shell_script(xpra_file, starting_dir, socket_dir):
-    script = []
-    script.append("#!/bin/sh\n")
-    for var, value in os.environ.items():
-        # these aren't used by xpra, and some should not be exposed
-        # as they are either irrelevant or simply do not match
-        # the new environment used by xpra
-        # TODO: use a whitelist
-        if var in ["XDG_SESSION_COOKIE", "LS_COLORS", "DISPLAY"]:
-            continue
-        #XPRA_SOCKET_DIR is a special case, it is handled below
-        if var=="XPRA_SOCKET_DIR":
-            continue
-        if var=="XPRA_ALT_PYTHON_RETRY":
-            #the environment might have changed,
-            #and we may need to retry with a different interpreter
-            #different from the one that created this script
-            continue
-        if var.startswith("BASH_FUNC"):
-            #some versions of bash will apparently generate functions
-            #that cannot be reloaded using this script
-            continue
-        # :-separated envvars that people might change while their server is
-        # going:
-        if var in ("PATH", "LD_LIBRARY_PATH", "PYTHONPATH"):
-            #prevent those paths from accumulating the same values multiple times,
-            #only keep the first one:
-            pval = value.split(os.pathsep)      #ie: ["/usr/bin", "/usr/local/bin", "/usr/bin"]
-            seen = set()
-            value = os.pathsep.join(x for x in pval if not (x in seen or seen.add(x)))
-            script.append("%s=%s:\"$%s\"; export %s\n"
-                          % (var, sh_quotemeta(value), var, var))
-        else:
-            script.append("%s=%s; export %s\n"
-                          % (var, sh_quotemeta(value), var))
-    #XPRA_SOCKET_DIR is a special case, we want to honour it
-    #when it is specified, but the client may override it:
-    if socket_dir:
-        script.append('if [ -z "${XPRA_SOCKET_DIR}" ]; then\n')
-        script.append('    XPRA_SOCKET_DIR=%s; export XPRA_SOCKET_DIR\n' % sh_quotemeta(os.path.expanduser(socket_dir)))
-        script.append('fi\n')
-    # We ignore failures in cd'ing, b/c it's entirely possible that we were
-    # started from some temporary directory and all paths are absolute.
-    script.append("cd %s\n" % sh_quotemeta(starting_dir))
-    if OSX:
-        #OSX contortions:
-        #The executable is the python interpreter,
-        #which is execed by a shell script, which we have to find..
-        sexec = sys.executable
-        bini = sexec.rfind("Resources/bin/")
-        if bini>0:
-            sexec = os.path.join(sexec[:bini], "Resources", "MacOS", "Xpra")
-        script.append("_XPRA_SCRIPT=%s\n" % (sh_quotemeta(sexec),))
-        script.append("""
-if which "$_XPRA_SCRIPT" > /dev/null; then
-    # Happypath:
-    exec "$_XPRA_SCRIPT" "$@"
-else
-    # Hope for the best:
-    exec Xpra "$@"
-fi
-""")
+
+# credit: https://stackoverflow.com/a/47080959/428751
+# returns a dictionary of the environment variables resulting from sourcing a file
+def env_from_sourcing(file_to_source_path, include_unexported_variables=False):
+    import json
+    import subprocess
+    from xpra.log import Logger
+    log = Logger("exec")
+    filename = file_to_source_path
+    if not os.path.exists(file_to_source_path):
+        filename = which(file_to_source_path)
+        if not filename:
+            log.error("Error: cannot find file '%s' to source", file_to_source_path)
+            return {}
+    if not os.path.isabs(filename):
+        filename = os.path.abspath(filename)
+    #figure out if this is a script to source,
+    #or if we're meant to execute it directly
+    try:
+        with open(filename, 'rb') as f:
+            first_line = f.readline()
+    except OSError as e:
+        log.error("Error: failed to read from '%s'", filename)
+        log.error(" %s", e)
+        first_line = b""
+    if first_line.startswith(b"\x7fELF") or b"\x00" in first_line:
+        cmd = [filename]
+        def decode(out):
+            env = {}
+            for line in out.splitlines():
+                parts = line.split("=", 1)
+                if len(parts)==2:
+                    env[parts[0]] = parts[1]
+            log("decode(%r)=%s", out, env)
+            return env
     else:
-        script.append("_XPRA_PYTHON=%s\n" % (sh_quotemeta(sys.executable),))
-        script.append("_XPRA_SCRIPT=%s\n" % (sh_quotemeta(xpra_file),))
-        script.append("""
+        source = '%ssource %s' % ("set -a && " if include_unexported_variables else "", filename)
+        dump = '/usr/bin/python -c "import os, json;print(json.dumps(dict(os.environ)))"'
+        cmd = ['/bin/bash', '-c', '%s && %s' % (source, dump)]
+        def decode(out):
+            try:
+                env = json.loads(out)
+                log("json loads(%r)=%s", out, env)
+                return env
+            except json.decoder.JSONDecodeError:
+                log.error("Error decoding json output from sourcing script '%s'",
+                          file_to_source_path, exc_info=True)
+                return {}
+    try:
+        log("env_from_sourcing%s cmd=%s", (filename, include_unexported_variables), cmd)
+        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE)
+        out = proc.communicate()[0]
+        if proc.returncode!=0:
+            log.error("Error %i running source script '%s'", proc.returncode, filename)
+    except OSError as e:
+        log("env_from_sourcing%s", (filename, include_unexported_variables), exc_info=True)
+        log(" stdout=%r (%s)", out, type(out))
+        log.error("Error running source script '%s'", proc.returncode, file_to_source_path)
+        log.error(" %s", e)
+        return {}
+    log("stdout(%s)=%r", filename, out)
+    if not out:
+        return {}
+    try:
+        out = out.decode()
+    except UnicodeDecodeError:
+        log.error("Error decoding output from '%s'", filename, exc_info=True)
+        return {}
+    return decode(out)
+
+
+if PYTHON3:
+    def sh_quotemeta(s):
+        return b"'" + s.replace(b"'", b"'\\''") + b"'"
+
+    def xpra_runner_shell_script(xpra_file, starting_dir, socket_dir):
+        script = []
+        script.append(b"#!/bin/sh\n")
+        for var, value in os.environb.items():
+            # these aren't used by xpra, and some should not be exposed
+            # as they are either irrelevant or simply do not match
+            # the new environment used by xpra
+            # TODO: use a whitelist
+            if var in (b"XDG_SESSION_COOKIE", b"LS_COLORS", b"DISPLAY"):
+                continue
+            #XPRA_SOCKET_DIR is a special case, it is handled below
+            if var==b"XPRA_SOCKET_DIR":
+                continue
+            if var==b"XPRA_ALT_PYTHON_RETRY":
+                #the environment might have changed,
+                #and we may need to retry with a different interpreter
+                #different from the one that created this script
+                continue
+            if var.startswith(b"BASH_FUNC"):
+                #some versions of bash will apparently generate functions
+                #that cannot be reloaded using this script
+                continue
+            # :-separated envvars that people might change while their server is
+            # going:
+            if var in (b"PATH", b"LD_LIBRARY_PATH", b"PYTHONPATH"):
+                #prevent those paths from accumulating the same values multiple times,
+                #only keep the first one:
+                pathsep = os.pathsep.encode()
+                pval = value.split(pathsep)      #ie: ["/usr/bin", "/usr/local/bin", "/usr/bin"]
+                seen = set()
+                value = pathsep.join(x for x in pval if not (x in seen or seen.add(x)))
+                script.append(b"%s=%s:\"$%s\"; export %s\n"
+                              % (var, sh_quotemeta(value), var, var))
+            else:
+                script.append(b"%s=%s; export %s\n"
+                              % (var, sh_quotemeta(value), var))
+        #XPRA_SOCKET_DIR is a special case, we want to honour it
+        #when it is specified, but the client may override it:
+        if socket_dir:
+            script.append(b'if [ -z "${XPRA_SOCKET_DIR}" ]; then\n')
+            script.append(b'    XPRA_SOCKET_DIR=%s; export XPRA_SOCKET_DIR\n' % sh_quotemeta(os.path.expanduser(socket_dir).encode()))
+            script.append(b'fi\n')
+        # We ignore failures in cd'ing, b/c it's entirely possible that we were
+        # started from some temporary directory and all paths are absolute.
+        script.append(b"cd %s\n" % sh_quotemeta(starting_dir.encode()))
+        if OSX:
+            #OSX contortions:
+            #The executable is the python interpreter,
+            #which is execed by a shell script, which we have to find..
+            sexec = sys.executable
+            bini = sexec.rfind("Resources/bin/")
+            if bini>0:
+                sexec = os.path.join(sexec[:bini], "Resources", "MacOS", "Xpra")
+            script.append(b"_XPRA_SCRIPT=%s\n" % (sh_quotemeta(sexec.encode()),))
+            script.append(b"""
+    if which "$_XPRA_SCRIPT" > /dev/null; then
+        # Happypath:
+        exec "$_XPRA_SCRIPT" "$@"
+    else
+        # Hope for the best:
+        exec Xpra "$@"
+    fi
+    """)
+        else:
+            script.append(b"_XPRA_PYTHON=%s\n" % (sh_quotemeta(sys.executable.encode()),))
+            script.append(b"_XPRA_SCRIPT=%s\n" % (sh_quotemeta(xpra_file.encode()),))
+            script.append(b"""
 if which "$_XPRA_PYTHON" > /dev/null && [ -e "$_XPRA_SCRIPT" ]; then
     # Happypath:
     exec "$_XPRA_PYTHON" "$_XPRA_SCRIPT" "$@"
@@ -93,7 +175,93 @@ END
     exec xpra "$@"
 fi
 """)
-    return "".join(script)
+        return b"".join(script)
+
+else:
+    #PYTHON2:
+
+    def sh_quotemeta(s):
+        return "'" + s.replace("'", "'\\''") + "'"
+
+    def xpra_runner_shell_script(xpra_file, starting_dir, socket_dir):
+        script = []
+        script.append("#!/bin/sh\n")
+        for var, value in os.environ.items():
+            # these aren't used by xpra, and some should not be exposed
+            # as they are either irrelevant or simply do not match
+            # the new environment used by xpra
+            # TODO: use a whitelist
+            if var in ["XDG_SESSION_COOKIE", "LS_COLORS", "DISPLAY"]:
+                continue
+            #XPRA_SOCKET_DIR is a special case, it is handled below
+            if var=="XPRA_SOCKET_DIR":
+                continue
+            if var=="XPRA_ALT_PYTHON_RETRY":
+                #the environment might have changed,
+                #and we may need to retry with a different interpreter
+                #different from the one that created this script
+                continue
+            if var.startswith("BASH_FUNC"):
+                #some versions of bash will apparently generate functions
+                #that cannot be reloaded using this script
+                continue
+            # :-separated envvars that people might change while their server is
+            # going:
+            if var in ("PATH", "LD_LIBRARY_PATH", "PYTHONPATH"):
+                #prevent those paths from accumulating the same values multiple times,
+                #only keep the first one:
+                pval = value.split(os.pathsep)      #ie: ["/usr/bin", "/usr/local/bin", "/usr/bin"]
+                seen = set()
+                value = os.pathsep.join(x for x in pval if not (x in seen or seen.add(x)))
+                script.append("%s=%s:\"$%s\"; export %s\n"
+                              % (var, sh_quotemeta(value), var, var))
+            else:
+                script.append("%s=%s; export %s\n"
+                              % (var, sh_quotemeta(value), var))
+        #XPRA_SOCKET_DIR is a special case, we want to honour it
+        #when it is specified, but the client may override it:
+        if socket_dir:
+            script.append('if [ -z "${XPRA_SOCKET_DIR}" ]; then\n')
+            script.append('    XPRA_SOCKET_DIR=%s; export XPRA_SOCKET_DIR\n' % sh_quotemeta(os.path.expanduser(socket_dir)))
+            script.append('fi\n')
+        # We ignore failures in cd'ing, b/c it's entirely possible that we were
+        # started from some temporary directory and all paths are absolute.
+        script.append("cd %s\n" % sh_quotemeta(starting_dir))
+        if OSX:
+            #OSX contortions:
+            #The executable is the python interpreter,
+            #which is execed by a shell script, which we have to find..
+            sexec = sys.executable
+            bini = sexec.rfind("Resources/bin/")
+            if bini>0:
+                sexec = os.path.join(sexec[:bini], "Resources", "MacOS", "Xpra")
+            script.append("_XPRA_SCRIPT=%s\n" % (sh_quotemeta(sexec),))
+            script.append("""
+    if which "$_XPRA_SCRIPT" > /dev/null; then
+        # Happypath:
+        exec "$_XPRA_SCRIPT" "$@"
+    else
+        # Hope for the best:
+        exec Xpra "$@"
+    fi
+    """)
+        else:
+            script.append("_XPRA_PYTHON=%s\n" % (sh_quotemeta(sys.executable),))
+            script.append("_XPRA_SCRIPT=%s\n" % (sh_quotemeta(xpra_file),))
+            script.append("""
+if which "$_XPRA_PYTHON" > /dev/null && [ -e "$_XPRA_SCRIPT" ]; then
+    # Happypath:
+    exec "$_XPRA_PYTHON" "$_XPRA_SCRIPT" "$@"
+else
+    cat >&2 <<END
+    Could not find one or both of '$_XPRA_PYTHON' and '$_XPRA_SCRIPT'
+    Perhaps your environment has changed since the xpra server was started?
+    I'll just try executing 'xpra' with current PATH, and hope...
+END
+    exec xpra "$@"
+fi
+""")
+        return "".join(script).encode()
 
 def write_runner_shell_scripts(contents, overwrite=True):
     # This used to be given a display-specific name, but now we give it a
@@ -127,7 +295,7 @@ def write_runner_shell_scripts(contents, overwrite=True):
             with umask_context(0o022):
                 h = os.open(scriptpath, os.O_WRONLY|os.O_CREAT|os.O_TRUNC, 0o700)
                 try:
-                    os.write(h, contents.encode())
+                    os.write(h, contents)
                 finally:
                     os.close(h)
         except Exception as e:
