@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
-# Copyright (C) 2010-2018 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2010-2019 Antoine Martin <antoine@xpra.org>
 # Copyright (C) 2008 Nathaniel Smith <njs@pobox.com>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
 from collections import deque
 
-from xpra.log import Logger
-log = Logger("clipboard")
-
-from xpra.net.compression import Compressible
+from xpra.net.compression import Compressible, compressed_wrapper
 from xpra.server.source.stub_source_mixin import StubSourceMixin
 from xpra.platform.features import CLIPBOARDS
-from xpra.util import envint, XPRA_CLIPBOARD_NOTIFICATION_ID
+from xpra.util import envint
 from xpra.os_util import monotonic_time
+from xpra.log import Logger
+
+log = Logger("clipboard")
 
 MAX_CLIPBOARD_LIMIT = envint("XPRA_CLIPBOARD_LIMIT", 30)
 MAX_CLIPBOARD_LIMIT_DURATION = envint("XPRA_CLIPBOARD_LIMIT_DURATION", 3)
@@ -36,6 +36,7 @@ class ClipboardConnection(StubSourceMixin):
         self.clipboard_greedy = False
         self.clipboard_want_targets = False
         self.clipboard_client_selections = CLIPBOARDS
+        self.clipboard_preferred_targets = ()
 
     def cleanup(self):
         self.cancel_clipboard_progress_timer()
@@ -44,16 +45,31 @@ class ClipboardConnection(StubSourceMixin):
         self.clipboard_enabled = c.boolget("clipboard", False)
         self.clipboard_notifications = c.boolget("clipboard.notifications")
         self.clipboard_set_enabled = c.boolget("clipboard.set_enabled")
-        log("client clipboard: enabled=%s, notifications=%s, set-enabled=%s", self.clipboard_enabled, self.clipboard_notifications, self.clipboard_set_enabled)
+        log("client clipboard: enabled=%s, notifications=%s, set-enabled=%s",
+            self.clipboard_enabled, self.clipboard_notifications, self.clipboard_set_enabled)
         self.clipboard_greedy = c.boolget("clipboard.greedy")
         self.clipboard_want_targets = c.boolget("clipboard.want_targets")
         self.clipboard_client_selections = c.strlistget("clipboard.selections", CLIPBOARDS)
-        log("client clipboard: greedy=%s, want_targets=%s, client_selections=%s", self.clipboard_greedy, self.clipboard_want_targets, self.clipboard_client_selections)
+        self.clipboard_contents_slice_fix = c.boolget("clipboard.contents-slice-fix")
+        self.clipboard_preferred_targets = c.strlistget("clipboard.preferred-targets", ())
+        log("client clipboard: greedy=%s, want_targets=%s, client_selections=%s, contents_slice_fix=%s",
+            self.clipboard_greedy, self.clipboard_want_targets,
+            self.clipboard_client_selections, self.clipboard_contents_slice_fix)
+        if self.clipboard_enabled and not self.clipboard_contents_slice_fix:
+            log.info("client clipboard does not include contents slice fix")
 
     def get_info(self):
         return {
-            "clipboard"                 : self.clipboard_enabled,
-            "clipboard_notifications"   : True,
+            "clipboard" : {
+                "enabled"               : self.clipboard_enabled,
+                "notifications"         : self.clipboard_notifications,
+                "set-enabled"           : self.clipboard_set_enabled,
+                "greedy"                : self.clipboard_greedy,
+                "want-targets"          : self.clipboard_want_targets,
+                "preferred-targets"     : self.clipboard_preferred_targets,
+                "selections"            : self.clipboard_client_selections,
+                "contents-slice-fix"    : self.clipboard_contents_slice_fix,
+                },
             }
 
 
@@ -102,13 +118,6 @@ class ClipboardConnection(StubSourceMixin):
                 log("%i events in the last %i seconds: %s", len(events), MAX_CLIPBOARD_LIMIT_DURATION, events)
                 if len(events)>=MAX_CLIPBOARD_LIMIT*MAX_CLIPBOARD_LIMIT_DURATION:
                     log.warn(" limit sustained for more than %i seconds,", MAX_CLIPBOARD_LIMIT_DURATION)
-                    log.warn(" the clipboard is now disabled")
-                    self.clipboard_enabled = False
-                    body = "Too many clipboard requests,\n"+\
-                           "a clipboard synchronization loop may be causing this problem,\n"+\
-                           "or an overly aggressive clipboard manager perhaps?"
-                    self.send_clipboard_enabled(msg)
-                    self.may_notify(XPRA_CLIPBOARD_NOTIFICATION_ID, "Clipboard synchronization is now disabled", body, icon_name="clipboard")
                 return
         #call compress_clibboard via the encode work queue:
         self.queue_encode((True, self.compress_clipboard, packet))
@@ -116,8 +125,11 @@ class ClipboardConnection(StubSourceMixin):
     def compress_clipboard(self, packet):
         #Note: this runs in the 'encode' thread!
         packet = list(packet)
-        for i in range(len(packet)):
-            v = packet[i]
-            if type(v)==Compressible:
-                packet[i] = self.compressed_wrapper(v.datatype, v.data)
+        for i, item in enumerate(packet):
+            if isinstance(item, Compressible):
+                if self.brotli:
+                    packet[i] = compressed_wrapper(item.datatype, item.data,
+                                                               level=9, brotli=True, can_inline=False)
+                else:
+                    packet[i] = self.compressed_wrapper(item.datatype, item.data)
         self.queue_packet(packet)
