@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
-# Copyright (C) 2010-2018 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2010-2018 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-from xpra.log import Logger
-log = Logger("timeout")
-
 from xpra.util import envint, IDLE_TIMEOUT, XPRA_IDLE_NOTIFICATION_ID
 from xpra.os_util import monotonic_time
 from xpra.server.source.stub_source_mixin import StubSourceMixin
+from xpra.log import Logger
+
+log = Logger("timeout")
 
 GRACE_PERCENT = envint("XPRA_GRACE_PERCENT", 90)
 
@@ -107,7 +107,9 @@ class IdleMixin(StubSourceMixin):
         summary += " is about to timeout"
         body = "Unless this session sees some activity,\n" + \
                "it will be terminated soon."
-        self.may_notify(nid, summary, body, actions, {}, expire_timeout=10*1000, icon_name="timer", user_callback=self.idle_notification_action)
+        self.may_notify(nid, summary, body,
+                        actions, {}, expire_timeout=10*1000,
+                        icon_name="timer", user_callback=self.idle_notification_action)
         self.go_idle()
 
     def idle_notification_action(self, nid, action_id):
