@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # This file is part of Xpra.
-# Copyright (C) 2016-2018 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2016-2018 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -22,6 +22,7 @@ WAVPACK = "wavpack"
 OGG = "ogg"
 MKA = "mka"
 MPEG4 = "mpeg4"
+ID3V2 = "id3v2"
 #RTP = "rtp"
 RAW = "raw"
 
@@ -40,6 +41,7 @@ AAC_MPEG4   = AAC+"+"+MPEG4
 WAV_LZ4     = WAV+"+"+LZ4
 WAV_LZO     = WAV+"+"+LZO
 MP3_MPEG4   = MP3+"+"+MPEG4
+MP3_ID3V2   = MP3+"+"+ID3V2
 
 
 #used for parsing codec names specified on the command line:
@@ -58,7 +60,7 @@ def sound_option_or_all(name, options, all_values):
                     invalid_options.append(o)
                 else:
                     v.append(o)
-        if len(invalid_options)>0:
+        if invalid_options:
             if all_values:
                 log.warn("Warning: invalid value%s for %s: %s", engs(invalid_options), name, csv(invalid_options))
                 log.warn(" valid option%s: %s", engs(all_values), csv(all_values))
