@@ -8,10 +8,11 @@ import os
 import socket
 
 from xpra.os_util import get_generic_os_name, load_binary_file, PYTHON3
-from xpra.util import updict, log_screen_sizes
+from xpra.util import updict, log_screen_sizes, envbool
 from xpra.platform.paths import get_icon, get_icon_filename
 from xpra.platform.gui import get_wm_name
 from xpra.server import server_features
+from xpra.server.source.windows_mixin import WindowsMixin
 from xpra.gtk_common.gobject_util import one_arg_signal, no_arg_signal
 from xpra.gtk_common.gobject_compat import import_glib
 from xpra.gtk_common.error import XError
@@ -52,6 +53,8 @@ metadatalog = Logger("x11", "metadata")
 screenlog = Logger("screen")
 iconlog = Logger("icon")
 
+MODIFY_GSETTINGS = envbool("XPRA_MODIFY_GSETTINGS", True)
+
 
 class DesktopModel(WindowModelStub, WindowDamageHandler):
     __gsignals__ = {}
@@ -297,6 +300,7 @@ class XpraDesktopServer(DesktopServerBaseClass):
         self.session_type = "desktop"
         self.resize_timer = None
         self.resize_value = None
+        self.gsettings_modified = {}
 
     def init(self, opts):
         for c in DESKTOPSERVER_BASES:
@@ -322,11 +326,51 @@ class XpraDesktopServer(DesktopServerBaseClass):
         add_catchall_receiver("xpra-xkb-event", self)
         X11Keyboard.selectBellNotification(True)
 
+        if MODIFY_GSETTINGS:
+            self.modify_gsettings()
+
+    def modify_gsettings(self):
+        #try to suspend animations:
+        self.gsettings_modified = self.do_modify_gsettings({
+            "org.mate.interface" : ("gtk-enable-animations", "enable-animations"),
+            "org.gnome.desktop.interface" : ("enable-animations",),
+            "com.deepin.wrap.gnome.desktop.interface" : ("enable-animations",),
+            })
+
+    def do_modify_gsettings(self, defs, value=False):
+        if not PYTHON3:
+            #can't be done with Python2?
+            return
+        modified = {}
+        from gi.repository import Gio
+        schemas = Gio.Settings.list_schemas()
+        for schema, attributes in defs.items():
+            if schema not in schemas:
+                continue
+            try:
+                s = Gio.Settings.new(schema)
+                restore = []
+                for attribute in attributes:
+                    v = s.get_boolean(attribute)
+                    if v:
+                        s.set_boolean(attribute, value)
+                        restore.append(attribute)
+                if restore:
+                    modified[schema] = restore
+            except Exception as e:
+                log("error accessing schema '%s' and attributes %s", schema, attributes, exc_info=True)
+                log.error("Error accessing schema '%s' and attributes %s:", schema, csv(attributes))
+                log.error(" %s", e)
+        return modified
     def do_cleanup(self):
         self.cancel_resize_timer()
         remove_catchall_receiver("xpra-motion-event", self)
         X11ServerBase.do_cleanup(self)
+        if MODIFY_GSETTINGS:
+            self.restore_gsettings()
 
+    def restore_gsettings(self):
+        self.do_modify_gsettings(self.gsettings_modified, True)
 
     def notify_dpi_warning(self, body):
         pass
@@ -431,6 +475,7 @@ class XpraDesktopServer(DesktopServerBaseClass):
                 "configure.pointer"      : True,
                 "states"                 : ["iconified", "focused"],
                 })
+            capabilities["screen_sizes"] = get_screen_sizes()
         return capabilities
 
 
@@ -457,8 +502,9 @@ class XpraDesktopServer(DesktopServerBaseClass):
         x, y, w, h = window.get_geometry()
         geomlog("window_resized_signaled(%s) geometry=%s", window, (x, y, w, h))
         for ss in self._server_sources.values():
-            ss.resize_window(wid, window, w, h)
-            ss.damage(wid, window, 0, 0, w, h)
+            if isinstance(ss, WindowsMixin):
+                ss.resize_window(wid, window, w, h)
+                ss.damage(wid, window, 0, 0, w, h)
 
 
     def send_initial_windows(self, ss, sharing=False):
