@@ -1,5 +1,6 @@
 # This file is part of Xpra.
 # Copyright (C) 2008, 2009 Nathaniel Smith <njs@pobox.com>
+# Copyright (C) 2018 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -8,25 +9,29 @@
 # selection, we can either abort or steal it.  Once we have it, if someone
 # else steals it, then we should exit.
 
-import gobject
-import gtk
 from struct import pack, unpack, calcsize
 
+from xpra.gtk_common.gtk_util import (
+    gtk_main, gtk_main_quit, get_xwindow,
+    selectiondata_get_data, set_clipboard_data, wait_for_contents, GetClipboard,
+    STRUCTURE_MASK,
+    )
 from xpra.gtk_common.gobject_util import no_arg_signal, one_arg_signal
 from xpra.gtk_common.error import xsync, XError
 from xpra.x11.bindings.window_bindings import constants, X11WindowBindings #@UnresolvedImport
-X11Window = X11WindowBindings()
-
 from xpra.x11.gtk_x11.gdk_bindings import (
-                get_xatom,                  #@UnresolvedImport
-                get_pywindow,               #@UnresolvedImport
-                add_event_receiver,         #@UnresolvedImport
-                remove_event_receiver       #@UnresolvedImport
-                )
-
+    get_xatom,                  #@UnresolvedImport
+    get_pywindow,               #@UnresolvedImport
+    add_event_receiver,         #@UnresolvedImport
+    remove_event_receiver,      #@UnresolvedImport
+    )
+from xpra.gtk_common.gobject_compat import import_gtk, import_gobject, is_gtk3
 from xpra.log import Logger
+
 log = Logger("x11", "util")
 
+gtk = import_gtk()
+gobject = import_gobject()
 
 StructureNotifyMask = constants["StructureNotifyMask"]
 XNone = constants["XNone"]
@@ -45,14 +50,14 @@ class ManagerSelection(gobject.GObject):
     def __str__(self):
         return "ManagerSelection(%s)" % self.atom
 
-    def __init__(self, display, selection):
+    def __init__(self, selection):
         gobject.GObject.__init__(self)
         self.atom = selection
-        self.clipboard = gtk.Clipboard(display, selection)
+        self.clipboard = GetClipboard(selection)
         self._xwindow = None
 
     def _owner(self):
-        return X11Window.XGetSelectionOwner(self.atom)
+        return X11WindowBindings().XGetSelectionOwner(self.atom)
 
     def owned(self):
         "Returns True if someone owns the given selection."
@@ -72,10 +77,13 @@ class ManagerSelection(gobject.GObject):
         if when is self.IF_UNOWNED and old_owner != XNone:
             raise AlreadyOwned
 
-        self.clipboard.set_with_data([("VERSION", 0, 0)],
-                                     self._get,
-                                     self._clear,
-                                     None)
+        if is_gtk3():
+            set_clipboard_data(self.clipboard, "VERSION")
+        else:
+            self.clipboard.set_with_data([("VERSION", 0, 0)],
+	                                     self._get,
+	                                     self._clear,
+	                                     None)
 
         # Having acquired the selection, we have to announce our existence
         # (ICCCM 2.8, still).  The details here probably don't matter too
@@ -92,7 +100,9 @@ class ManagerSelection(gobject.GObject):
         # some weird tricks to get at these.
 
         # Ask ourselves when we acquired the selection:
-        ts_data = self.clipboard.wait_for_contents("TIMESTAMP").data
+        contents = wait_for_contents(self.clipboard, "TIMESTAMP")
+        ts_data = selectiondata_get_data(contents)
+
         #data is a timestamp, X11 datatype is Time which is CARD32,
         #(which is 64 bits on 64-bit systems!)
         Lsize = calcsize("@L")
@@ -104,10 +114,11 @@ class ManagerSelection(gobject.GObject):
         # Calculate the X atom for this selection:
         selection_xatom = get_xatom(self.atom)
         # Ask X what window we used:
-        self._xwindow = X11Window.XGetSelectionOwner(self.atom)
+        self._xwindow = X11WindowBindings().XGetSelectionOwner(self.atom)
 
         root = self.clipboard.get_display().get_default_screen().get_root_window()
-        X11Window.sendClientMessage(root.xid, root.xid, False, StructureNotifyMask,
+        xid = get_xwindow(root)
+        X11WindowBindings().sendClientMessage(xid, xid, False, StructureNotifyMask,
                           "MANAGER",
                           ts_num, selection_xatom, self._xwindow)
 
@@ -117,27 +128,45 @@ class ManagerSelection(gobject.GObject):
             try:
                 with xsync:
                     window = get_pywindow(self.clipboard, old_owner)
-                    window.set_events(window.get_events() | gtk.gdk.STRUCTURE_MASK)
+                    window.set_events(window.get_events() | STRUCTURE_MASK)
                 log("got window")
             except XError:
                 log("Previous owner is already gone, not blocking")
             else:
                 log("Waiting for previous owner to exit...")
                 add_event_receiver(window, self)
-                gtk.main()
+                gtk_main()
                 log("...they did.")
         window = get_pywindow(self.clipboard, self._xwindow)
         window.set_title("Xpra-ManagerSelection")
+        if is_gtk3():
+            #we can't use set_with_data(..),
+            #so we have to listen for owner-change:
+            self.clipboard.connect("owner-change", self._owner_change)
+
+    def _owner_change(self, clipboard, event):
+        log("owner_change(%s, %s)", clipboard, event)
+        if str(event.selection)!=self.atom:
+            #log("_owner_change(..) not our selection: %s vs %s", event.selection, self.atom)
+            return
+        if event.owner:
+            owner = event.owner.get_xid()
+            if owner==self._xwindow:
+                log("_owner_change(..) we still own %s", event.selection)
+                return
+        if self._xwindow:
+            self._xwindow = None
+            self.emit("selection-lost")
 
     def do_xpra_destroy_event(self, event):
         remove_event_receiver(event.window, self)
-        gtk.main_quit()
+        gtk_main_quit()
 
-    def _get(self, clipboard, outdata, which, userdata):
+    def _get(self, _clipboard, outdata, _which, _userdata):
         # We are compliant with ICCCM version 2.0 (see section 4.3)
         outdata.set("INTEGER", 32, pack("@ii", 2, 0))
 
-    def _clear(self, clipboard, userdata):
+    def _clear(self, _clipboard, _userdata):
         self._xwindow = None
         self.emit("selection-lost")
 
