@@ -1,6 +1,6 @@
 # This file is part of Xpra.
 # Copyright (C) 2008, 2009 Nathaniel Smith <njs@pobox.com>
-# Copyright (C) 2012-2017 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2012-2019 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -11,23 +11,17 @@ Functions for converting to and from X11 properties.
 """
 
 import struct
-import cairo
 
-from xpra.log import Logger
-log = Logger("x11", "window")
-
-from xpra.os_util import hexstr, StringIOClass, PYTHON3
-from xpra.codecs.argb.argb import premultiply_argb_in_place #@UnresolvedImport
+from xpra.os_util import hexstr, PYTHON3
 from xpra.x11.bindings.window_bindings import constants     #@UnresolvedImport
-from xpra.x11.bindings.window_bindings import X11WindowBindings #@UnresolvedImport
-X11Window = X11WindowBindings()
+from xpra.log import Logger
 
+log = Logger("x11", "window")
 
 if PYTHON3:
     long = int              #@ReservedAssignment
     unicode = str           #@ReservedAssignment
 
-
 USPosition      = constants["USPosition"]
 PPosition       = constants["PPosition"]
 PMaxSize        = constants["PMaxSize"]
@@ -43,7 +37,7 @@ IconicState     = constants["IconicState"]
 InputHint       = constants["InputHint"]
 
 
-def unsupported(*args):
+def unsupported(*_args):
     raise Exception("unsupported")
 
 def _force_length(name, data, length, noerror_length=None):
@@ -53,7 +47,7 @@ def _force_length(name, data, length, noerror_length=None):
         log.warn("Odd-lengthed property %s: wanted %s bytes, got %s: %r"
                  % (name, length, len(data), data))
     # Zero-pad data
-    data += "\0" * length
+    data += b"\0" * length
     return data[:length]
 
 
@@ -64,15 +58,16 @@ class NetWMStrut(object):
         # will be only length 4 instead of 12, we just don't define the other values
         # and let the client deal with it appropriately
         if len(data)==16:
-            self.left, self.right, self.top, self.bottom = struct.unpack("=IIII", data)
+            self.left, self.right, self.top, self.bottom = struct.unpack(b"@LLLL", data)
         else:
             data = _force_length("_NET_WM_STRUT or _NET_WM_STRUT_PARTIAL", data, 4 * 12)
-            (self.left, self.right, self.top, self.bottom,
-             self.left_start_y, self.left_end_y,
-             self.right_start_y, self.right_end_y,
-             self.top_start_x, self.top_end_x,
-             self.bottom_start_x, self.bottom_stop_x,
-             ) = struct.unpack("=" + "I" * 12, data)
+            (
+                self.left, self.right, self.top, self.bottom,
+                self.left_start_y, self.left_end_y,
+                self.right_start_y, self.right_end_y,
+                self.top_start_x, self.top_end_x,
+                self.bottom_start_x, self.bottom_stop_x,
+                ) = struct.unpack(b"@" + b"L" * 12, data)
 
     def todict(self):
         return self.__dict__
@@ -84,9 +79,10 @@ class NetWMStrut(object):
 class MotifWMHints(object):
     def __init__(self, _disp, data):
         #some applications use the wrong size (ie: blender uses 16) so pad it:
-        pdata = _force_length("_MOTIF_WM_HINTS", data, 20, 16)
+        sizeof_long = struct.calcsize(b"@L")
+        pdata = _force_length("_MOTIF_WM_HINTS", data, sizeof_long*5, sizeof_long*4)
         self.flags, self.functions, self.decorations, self.input_mode, self.status = \
-            struct.unpack("=IIIiI", pdata)
+            struct.unpack(b"@LLLlL", pdata)
         log("MotifWMHints(%s)=%s", hexstr(data), self)
 
     #found in mwmh.h:
@@ -130,50 +126,50 @@ class MotifWMHints(object):
     TEAROFF_WINDOW  = 0
 
     FLAGS_STR = {
-                 FUNCTIONS_BIT      : "functions",
-                 DECORATIONS_BIT    : "decorations",
-                 INPUT_MODE_BIT     : "input",
-                 STATUS_BIT         : "status",
-                 }
+        FUNCTIONS_BIT      : "functions",
+        DECORATIONS_BIT    : "decorations",
+        INPUT_MODE_BIT     : "input",
+        STATUS_BIT         : "status",
+        }
     FUNCTIONS_STR = {
-                     ALL_BIT        : "all",
-                     RESIZE_BIT     : "resize",
-                     MOVE_BIT       : "move",
-                     MINIMIZE_BIT   : "minimize",
-                     MAXIMIZE_BIT   : "maximize",
-                     CLOSE_BIT      : "close",
-                     SHADE_BIT      : "shade",
-                     STICK_BIT      : "stick",
-                     FULLSCREEN_BIT : "fullscreen",
-                     ABOVE_BIT      : "above",
-                     BELOW_BIT      : "below",
-                     MAXIMUS_BIT    : "maximus",
-                     }
+        ALL_BIT        : "all",
+        RESIZE_BIT     : "resize",
+        MOVE_BIT       : "move",
+        MINIMIZE_BIT   : "minimize",
+        MAXIMIZE_BIT   : "maximize",
+        CLOSE_BIT      : "close",
+        SHADE_BIT      : "shade",
+        STICK_BIT      : "stick",
+        FULLSCREEN_BIT : "fullscreen",
+        ABOVE_BIT      : "above",
+        BELOW_BIT      : "below",
+        MAXIMUS_BIT    : "maximus",
+        }
     DECORATIONS_STR = {
-                       ALL_BIT      : "all",
-                       BORDER_BIT   : "border",
-                       RESIZEH_BIT  : "resizeh",
-                       TITLE_BIT    : "title",
-                       MENU_BIT     : "menu",
-                       MINIMIZE_BIT : "minimize",
-                       MAXIMIZE_BIT : "maximize",
-                       }
+        ALL_BIT      : "all",
+        BORDER_BIT   : "border",
+        RESIZEH_BIT  : "resizeh",
+        TITLE_BIT    : "title",
+        MENU_BIT     : "menu",
+        MINIMIZE_BIT : "minimize",
+        MAXIMIZE_BIT : "maximize",
+        }
     INPUT_STR = {
-                 MODELESS                   : "modeless",
-                 PRIMARY_APPLICATION_MODAL  : "primary-application-modal",
-                 SYSTEM_MODAL               : "system-modal",
-                 FULL_APPLICATION_MODAL     : "full-application-modal",
-                 }
+        MODELESS                   : "modeless",
+        PRIMARY_APPLICATION_MODAL  : "primary-application-modal",
+        SYSTEM_MODAL               : "system-modal",
+        FULL_APPLICATION_MODAL     : "full-application-modal",
+        }
 
     STATUS_STR = {
         TEAROFF_WINDOW : "tearoff",
         }
 
     def bits_to_strs(self, int_val, flag_bit, dict_str):
-        if flag_bit and not (self.flags & (2**flag_bit)):
+        if flag_bit and not self.flags & (2**flag_bit):
             #the bit is not set, ignore this attribute
-            return[]
-        return [v for k,v in dict_str.items() if (int_val & (2**k))]
+            return ()
+        return tuple(v for k,v in dict_str.items() if int_val & (2**k))
     def flags_strs(self):
         return self.bits_to_strs(self.flags,
                                  0,
@@ -196,60 +192,52 @@ class MotifWMHints(object):
                                  MotifWMHints.STATUS_STR)
 
     def __str__(self):
-        return "MotifWMHints(%s)" % {"flags"        : self.flags_strs(),
-                                     "functions"    : self.functions_strs(),
-                                     "decorations"  : self.decorations_strs(),
-                                     "input_mode"   : self.input_strs(),
-                                     "status"       : self.status_strs(),
-                                     }
+        return "MotifWMHints(%s)" % {
+            "flags"         : self.flags_strs(),
+            "functions"     : self.functions_strs(),
+            "decorations"   : self.decorations_strs(),
+            "input_mode"    : self.input_strs(),
+            "status"        : self.status_strs(),
+            }
 
 
 def _read_image(_disp, stream):
     try:
-        header = stream.read(2 * 4)
+        int_size = struct.calcsize(b"@I")
+        long_size = struct.calcsize(b"@L")
+        header = stream.read(long_size*2)
         if not header:
             return None
-        (width, height) = struct.unpack("=II", header)
-        data = stream.read(width * height * 4)
-        if len(data) < width * height * 4:
-            log.warn("Corrupt _NET_WM_ICON")
+        width, height = struct.unpack(b"@LL", header)
+        data = stream.read(width * height * long_size)
+        expected = width * height * long_size
+        if len(data) < expected:
+            log.warn("Warning: corrupt _NET_WM_ICON, execpted %i bytes but got %i",
+                     expected, len(data))
             return None
-    except Exception as e:
-        log.warn("Weird corruption in _NET_WM_ICON: %s", e)
+        if int_size!=long_size:
+            #long to ints (CARD32):
+            longs = struct.unpack(b"@"+b"l"*(width*height), data)
+            data = struct.pack(b"@"+b"i"*(width*height), *longs)
+    except Exception:
+        log.warn("Weird corruption in _NET_WM_ICON", exc_info=True)
         return None
-    # Cairo wants a native-endian array here, and since the icon is
-    # transmitted as CARDINALs, that's what we get. It might seem more
-    # sensible to use ImageSurface.create_for_data (at least it did to me!)
-    # but then you end up with a surface that refers to the memory you pass in
-    # directly, and also .get_data() doesn't work on it, and it breaks the
-    # test suite and blah. This at least works, as odd as it is:
-    surf = cairo.ImageSurface(cairo.FORMAT_ARGB32, width, height)
-    # old versions of cairo do not have this method, just ignore it
-    if not hasattr(surf, "get_data"):
-        log.warn("Your Cairo is too old! Carrying on as best I can, "
-                 "but don't expect a miracle")
-        return None
-    surf.get_data()[:] = data
-    # Cairo uses premultiplied alpha. EWMH actually doesn't specify what it
-    # uses, but apparently the de-facto standard is non-premultiplied. (At
-    # least that's what Compiz's sources say.)
-    premultiply_argb_in_place(surf.get_data())
-    return (width * height, surf)
+    return width, height, "BGRA", data
 
 # This returns a cairo ImageSurface which contains the largest icon defined in
 # a _NET_WM_ICON property.
 def NetWMIcons(disp, data):
     icons = []
-    stream = StringIOClass(data)
+    from io import BytesIO
+    stream = BytesIO(data)
     while True:
-        size_image = _read_image(disp, stream)
-        if size_image is None:
+        icon = _read_image(disp, stream)
+        if icon is None:
             break
-        icons.append(size_image)
+        icons.append(icon)
     if not icons:
         return None
-    icons.sort()
-    return icons[-1][1]
+    return icons
 
 
 def _to_latin1(_disp, v):
@@ -275,16 +263,16 @@ PROP_TYPES = {
     # that Xutf8TextPropertyToTextList exists.
     "latin1": (unicode, "STRING", 8, _to_latin1, _from_latin1, b"\0"),
     "state": ((int, long), "WM_STATE", 32,
-            lambda _disp, c: struct.pack("=I", c),
-            lambda _disp, d: struct.unpack("=I", d)[0],
+            lambda _disp, c: struct.pack(b"@L", c),
+            lambda _disp, d: struct.unpack(b"@L", d)[0],
             b""),
     "u32": ((int, long), "CARDINAL", 32,
-            lambda _disp, c: struct.pack("=I", c),
-            lambda _disp, d: struct.unpack("=I", d)[0],
+            lambda _disp, c: struct.pack(b"@L", c),
+            lambda _disp, d: struct.unpack(b"@L", d)[0],
             b""),
     "integer": ((int, long), "INTEGER", 32,
-            lambda _disp, c: struct.pack("=I", c),
-            lambda _disp, d: struct.unpack("=I", d)[0],
+            lambda _disp, c: struct.pack(b"@L", c),
+            lambda _disp, d: struct.unpack(b"@L", d)[0],
             b""),
     "strut": (NetWMStrut, "CARDINAL", 32,
               unsupported, NetWMStrut, None),
@@ -292,43 +280,38 @@ PROP_TYPES = {
                       unsupported, NetWMStrut, None),
     "motif-hints": (MotifWMHints, "_MOTIF_WM_HINTS", 32,
               unsupported, MotifWMHints, None),
-    "icon": (cairo.ImageSurface, "CARDINAL", 32,
+    "icons": (list, "CARDINAL", 32,
               unsupported, NetWMIcons, None),
-    # For uploading ad-hoc instances of the above complex structures to the
-    # server, so we can test reading them out again:
-    "debug-CARDINAL": (str, "CARDINAL", 32,
-                       lambda _disp, c: c,
-                       lambda _disp, d: d,
-                       None),
+    }
+
+PROP_SIZES = {
+    "icons" : 4*1024*1024,
     }
 
 
 def prop_encode(disp, etype, value):
-    if isinstance(etype, list):
+    if isinstance(etype, (list, tuple)):
         return _prop_encode_list(disp, etype[0], value)
-    else:
-        return _prop_encode_scalar(disp, etype, value)
+    return _prop_encode_scalar(disp, etype, value)
 
 def _prop_encode_scalar(disp, etype, value):
-    (pytype, atom, formatbits, serialize, _, _) = PROP_TYPES[etype]
+    pytype, atom, formatbits, serialize = PROP_TYPES[etype][:4]
     assert isinstance(value, pytype), "value for atom %s is not a %s: %s" % (atom, pytype, type(value))
     return (atom, formatbits, serialize(disp, value))
 
 def _prop_encode_list(disp, etype, value):
     (_, atom, formatbits, _, _, terminator) = PROP_TYPES[etype]
     value = tuple(value)
-    serialized = [_prop_encode_scalar(disp, etype, v)[2] for v in value]
-    no_none = [x for x in serialized if x is not None]
+    serialized = tuple(_prop_encode_scalar(disp, etype, v)[2] for v in value)
     # Strings in X really are null-separated, not null-terminated (ICCCM
     # 2.7.1, see also note in 4.1.2.5)
-    return (atom, formatbits, terminator.join(no_none))
+    return (atom, formatbits, terminator.join(x for x in serialized if x is not None))
 
 
 def prop_decode(disp, etype, data):
-    if isinstance(etype, list):
+    if isinstance(etype, (list, tuple)):
         return _prop_decode_list(disp, etype[0], data)
-    else:
-        return _prop_decode_scalar(disp, etype, data)
+    return _prop_decode_scalar(disp, etype, data)
 
 def _prop_decode_scalar(disp, etype, data):
     (pytype, _, _, _, deserialize, _) = PROP_TYPES[etype]
@@ -342,10 +325,12 @@ def _prop_decode_list(disp, etype, data):
         datums = data.split(terminator)
     else:
         datums = []
-        nbytes = formatbits // 8
+        if formatbits==32:
+            nbytes = struct.calcsize("@L")
+        else:
+            nbytes = formatbits // 8
         while data:
             datums.append(data[:nbytes])
             data = data[nbytes:]
-    props = [_prop_decode_scalar(disp, etype, datum) for datum in datums]
-    #assert None not in props
+    props = (_prop_decode_scalar(disp, etype, datum) for datum in datums)
     return [x for x in props if x is not None]
