@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
-# Copyright (C) 2017 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2017 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -18,11 +18,11 @@ def window_info(window):
 def dump_windows():
     from xpra.log import Logger
     log = Logger("x11", "window")
-    from gtk import gdk
-    root = gdk.get_default_root_window()
+    from xpra.gtk_common.gtk_util import get_default_root_window
+    root = get_default_root_window()
     log("root window: %s" % root)
     try:
-        from xpra.x11.gtk2.gdk_bindings import get_children #@UnresolvedImport
+        from xpra.x11.gtk_x11.gdk_bindings import get_children #@UnresolvedImport
     except ImportError:
         pass
     else:
