@@ -23,6 +23,7 @@ dbuslog = Logger("dbus")
 X11Keyboard = X11KeyboardBindings()
 
 SCALED_FONT_ANTIALIAS = envbool("XPRA_SCALED_FONT_ANTIALIAS", False)
+SYNC_ICC = envbool("XPRA_SYNC_ICC", True)
 
 
 def _get_antialias_hintstyle(antialias):
@@ -110,6 +111,14 @@ class X11ServerBase(X11ServerCore):
 
 
     def init_dbus(self, dbus_pid, dbus_env):
+        try:
+            from xpra.server.dbus import dbus_start
+            assert dbus_start
+        except ImportError as e:
+            log("init_dbus(%s, %s)", dbus_pid, dbus_env, exc_info=True)
+            log.warn("Warning: cannot initialize dbus")
+            log.warn(" %s", e)
+            return
         from xpra.server.dbus.dbus_start import (
             get_saved_dbus_pid, get_saved_dbus_env,
             save_dbus_pid, save_dbus_env,
@@ -189,6 +198,8 @@ class X11ServerBase(X11ServerCore):
 
 
     def set_icc_profile(self):
+        if not SYNC_ICC:
+            return
         ui_clients = [s for s in self._server_sources.values() if s.ui_client]
         if len(ui_clients)!=1:
             screenlog("%i UI clients, resetting ICC profile to default", len(ui_clients))
